#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or
# https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type
from ansible.plugins.action import ActionBase

try:
    from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
        AnsibleArgSpecValidator,
    )
except ImportError:
    ANSIBLE_UTILS_IS_INSTALLED = False
else:
    ANSIBLE_UTILS_IS_INSTALLED = True
from ansible.errors import AnsibleActionFail
from ansible_collections.cisco.dnac.plugins.plugin_utils.dnac import (
    DNACSDK,
    dnac_argument_spec,
    dnac_compare_equality,
    get_dict_result,
)
from ansible_collections.cisco.dnac.plugins.plugin_utils.exceptions import (
    InconsistentParameters,
)

# Get common arguments specification
argument_spec = dnac_argument_spec()
# Add arguments specific for this module
argument_spec.update(
    dict(
        state=dict(type="str", default="present", choices=["present", "absent"]),
        ssid=dict(type="str"),
        authType=dict(type="str"),
        passphrase=dict(type="str"),
        isFastLaneEnabled=dict(type="bool"),
        isMacFilteringEnabled=dict(type="bool"),
        ssidRadioType=dict(type="str"),
        isBroadcastSSID=dict(type="bool"),
        fastTransition=dict(type="str"),
        sessionTimeOutEnable=dict(type="bool"),
        sessionTimeOut=dict(type="int"),
        clientExclusionEnable=dict(type="bool"),
        clientExclusionTimeout=dict(type="int"),
        basicServiceSetMaxIdleEnable=dict(type="bool"),
        basicServiceSetClientIdleTimeout=dict(type="int"),
        directedMulticastServiceEnable=dict(type="bool"),
        neighborListEnable=dict(type="bool"),
        managementFrameProtectionClientprotection=dict(type="str"),
        nasOptions=dict(type="list"),
        profileName=dict(type="str"),
        aaaOverride=dict(type="bool"),
        coverageHoleDetectionEnable=dict(type="bool"),
        protectedManagementFrame=dict(type="str"),
        multiPSKSettings=dict(type="list"),
        clientRateLimit=dict(type="int"),
        rsnCipherSuiteGcmp256=dict(type="bool"),
        rsnCipherSuiteCcmp256=dict(type="bool"),
        rsnCipherSuiteGcmp128=dict(type="bool"),
        rsnCipherSuiteCcmp128=dict(type="bool"),
        ghz6PolicyClientSteering=dict(type="bool"),
        isAuthKey8021x=dict(type="bool"),
        isAuthKey8021xPlusFT=dict(type="bool"),
        isAuthKey8021x_SHA256=dict(type="bool"),
        isAuthKeySae=dict(type="bool"),
        isAuthKeySaePlusFT=dict(type="bool"),
        isAuthKeyPSK=dict(type="bool"),
        isAuthKeyPSKPlusFT=dict(type="bool"),
        isAuthKeyOWE=dict(type="bool"),
        isAuthKeyEasyPSK=dict(type="bool"),
        isAuthKeyPSKSHA256=dict(type="bool"),
        openSsid=dict(type="str"),
        wlanBandSelectEnable=dict(type="bool"),
        isEnabled=dict(type="bool"),
        authServers=dict(type="list"),
        acctServers=dict(type="list"),
        egressQos=dict(type="str"),
        ingressQos=dict(type="str"),
        wlanType=dict(type="str"),
        l3AuthType=dict(type="str"),
        authServer=dict(type="str"),
        externalAuthIpAddress=dict(type="str"),
        webPassthrough=dict(type="bool"),
        sleepingClientEnable=dict(type="bool"),
        sleepingClientTimeout=dict(type="int"),
        aclName=dict(type="str"),
        isPosturingEnabled=dict(type="bool"),
        isAuthKeySuiteB1x=dict(type="bool"),
        isAuthKeySuiteB1921x=dict(type="bool"),
        isAuthKeySaeExt=dict(type="bool"),
        isAuthKeySaeExtPlusFT=dict(type="bool"),
        isApBeaconProtectionEnabled=dict(type="bool"),
        ghz24Policy=dict(type="str"),
        cckmTsfTolerance=dict(type="int"),
        isCckmEnabled=dict(type="bool"),
        isHex=dict(type="bool"),
        isRandomMacFilterEnabled=dict(type="bool"),
        fastTransitionOverTheDistributedSystemEnable=dict(type="bool"),
        isRadiusProfilingEnabled=dict(type="bool"),
        policyProfileName=dict(type="str"),
        siteId=dict(type="str"),
        id=dict(type="str"),
        removeOverrideInHierarchy=dict(type="bool"),
    )
)

required_if = [
    ("state", "present", ["id", "siteId"], True),
    ("state", "absent", ["id", "siteId"], True),
]
required_one_of = []
mutually_exclusive = []
required_together = []


class SitesWirelessSettingsSsids(object):
    def __init__(self, params, dnac):
        self.dnac = dnac
        self.new_object = dict(
            ssid=params.get("ssid"),
            authType=params.get("authType"),
            passphrase=params.get("passphrase"),
            isFastLaneEnabled=params.get("isFastLaneEnabled"),
            isMacFilteringEnabled=params.get("isMacFilteringEnabled"),
            ssidRadioType=params.get("ssidRadioType"),
            isBroadcastSSID=params.get("isBroadcastSSID"),
            fastTransition=params.get("fastTransition"),
            sessionTimeOutEnable=params.get("sessionTimeOutEnable"),
            sessionTimeOut=params.get("sessionTimeOut"),
            clientExclusionEnable=params.get("clientExclusionEnable"),
            clientExclusionTimeout=params.get("clientExclusionTimeout"),
            basicServiceSetMaxIdleEnable=params.get("basicServiceSetMaxIdleEnable"),
            basicServiceSetClientIdleTimeout=params.get(
                "basicServiceSetClientIdleTimeout"
            ),
            directedMulticastServiceEnable=params.get("directedMulticastServiceEnable"),
            neighborListEnable=params.get("neighborListEnable"),
            managementFrameProtectionClientprotection=params.get(
                "managementFrameProtectionClientprotection"
            ),
            nasOptions=params.get("nasOptions"),
            profileName=params.get("profileName"),
            aaaOverride=params.get("aaaOverride"),
            coverageHoleDetectionEnable=params.get("coverageHoleDetectionEnable"),
            protectedManagementFrame=params.get("protectedManagementFrame"),
            multiPSKSettings=params.get("multiPSKSettings"),
            clientRateLimit=params.get("clientRateLimit"),
            rsnCipherSuiteGcmp256=params.get("rsnCipherSuiteGcmp256"),
            rsnCipherSuiteCcmp256=params.get("rsnCipherSuiteCcmp256"),
            rsnCipherSuiteGcmp128=params.get("rsnCipherSuiteGcmp128"),
            rsnCipherSuiteCcmp128=params.get("rsnCipherSuiteCcmp128"),
            ghz6PolicyClientSteering=params.get("ghz6PolicyClientSteering"),
            isAuthKey8021x=params.get("isAuthKey8021x"),
            isAuthKey8021xPlusFT=params.get("isAuthKey8021xPlusFT"),
            isAuthKey8021x_SHA256=params.get("isAuthKey8021x_SHA256"),
            isAuthKeySae=params.get("isAuthKeySae"),
            isAuthKeySaePlusFT=params.get("isAuthKeySaePlusFT"),
            isAuthKeyPSK=params.get("isAuthKeyPSK"),
            isAuthKeyPSKPlusFT=params.get("isAuthKeyPSKPlusFT"),
            isAuthKeyOWE=params.get("isAuthKeyOWE"),
            isAuthKeyEasyPSK=params.get("isAuthKeyEasyPSK"),
            isAuthKeyPSKSHA256=params.get("isAuthKeyPSKSHA256"),
            openSsid=params.get("openSsid"),
            wlanBandSelectEnable=params.get("wlanBandSelectEnable"),
            isEnabled=params.get("isEnabled"),
            authServers=params.get("authServers"),
            acctServers=params.get("acctServers"),
            egressQos=params.get("egressQos"),
            ingressQos=params.get("ingressQos"),
            wlanType=params.get("wlanType"),
            l3AuthType=params.get("l3AuthType"),
            authServer=params.get("authServer"),
            externalAuthIpAddress=params.get("externalAuthIpAddress"),
            webPassthrough=params.get("webPassthrough"),
            sleepingClientEnable=params.get("sleepingClientEnable"),
            sleepingClientTimeout=params.get("sleepingClientTimeout"),
            aclName=params.get("aclName"),
            isPosturingEnabled=params.get("isPosturingEnabled"),
            isAuthKeySuiteB1x=params.get("isAuthKeySuiteB1x"),
            isAuthKeySuiteB1921x=params.get("isAuthKeySuiteB1921x"),
            isAuthKeySaeExt=params.get("isAuthKeySaeExt"),
            isAuthKeySaeExtPlusFT=params.get("isAuthKeySaeExtPlusFT"),
            isApBeaconProtectionEnabled=params.get("isApBeaconProtectionEnabled"),
            ghz24Policy=params.get("ghz24Policy"),
            cckmTsfTolerance=params.get("cckmTsfTolerance"),
            isCckmEnabled=params.get("isCckmEnabled"),
            isHex=params.get("isHex"),
            isRandomMacFilterEnabled=params.get("isRandomMacFilterEnabled"),
            fastTransitionOverTheDistributedSystemEnable=params.get(
                "fastTransitionOverTheDistributedSystemEnable"
            ),
            isRadiusProfilingEnabled=params.get("isRadiusProfilingEnabled"),
            policyProfileName=params.get("policyProfileName"),
            site_id=params.get("siteId"),
            id=params.get("id"),
            remove_override_in_hierarchy=params.get("removeOverrideInHierarchy"),
        )

    def get_all_params(self, name=None, id=None):
        new_object_params = {}
        new_object_params["limit"] = self.new_object.get("limit")
        new_object_params["offset"] = self.new_object.get("offset")
        new_object_params["ssid"] = self.new_object.get("ssid")
        new_object_params["wlan_type"] = self.new_object.get(
            "wlanType"
        ) or self.new_object.get("wlan_type")
        new_object_params["auth_type"] = self.new_object.get(
            "authType"
        ) or self.new_object.get("auth_type")
        new_object_params["l3auth_type"] = self.new_object.get(
            "l3authType"
        ) or self.new_object.get("l3auth_type")
        new_object_params["site_id"] = self.new_object.get(
            "siteId"
        ) or self.new_object.get("site_id")
        return new_object_params

    def create_params(self):
        new_object_params = {}
        new_object_params["ssid"] = self.new_object.get("ssid")
        new_object_params["authType"] = self.new_object.get("authType")
        new_object_params["passphrase"] = self.new_object.get("passphrase")
        new_object_params["isFastLaneEnabled"] = self.new_object.get(
            "isFastLaneEnabled"
        )
        new_object_params["isMacFilteringEnabled"] = self.new_object.get(
            "isMacFilteringEnabled"
        )
        new_object_params["ssidRadioType"] = self.new_object.get("ssidRadioType")
        new_object_params["isBroadcastSSID"] = self.new_object.get("isBroadcastSSID")
        new_object_params["fastTransition"] = self.new_object.get("fastTransition")
        new_object_params["sessionTimeOutEnable"] = self.new_object.get(
            "sessionTimeOutEnable"
        )
        new_object_params["sessionTimeOut"] = self.new_object.get("sessionTimeOut")
        new_object_params["clientExclusionEnable"] = self.new_object.get(
            "clientExclusionEnable"
        )
        new_object_params["clientExclusionTimeout"] = self.new_object.get(
            "clientExclusionTimeout"
        )
        new_object_params["basicServiceSetMaxIdleEnable"] = self.new_object.get(
            "basicServiceSetMaxIdleEnable"
        )
        new_object_params["basicServiceSetClientIdleTimeout"] = self.new_object.get(
            "basicServiceSetClientIdleTimeout"
        )
        new_object_params["directedMulticastServiceEnable"] = self.new_object.get(
            "directedMulticastServiceEnable"
        )
        new_object_params["neighborListEnable"] = self.new_object.get(
            "neighborListEnable"
        )
        new_object_params["managementFrameProtectionClientprotection"] = (
            self.new_object.get("managementFrameProtectionClientprotection")
        )
        new_object_params["nasOptions"] = self.new_object.get("nasOptions")
        new_object_params["profileName"] = self.new_object.get("profileName")
        new_object_params["aaaOverride"] = self.new_object.get("aaaOverride")
        new_object_params["coverageHoleDetectionEnable"] = self.new_object.get(
            "coverageHoleDetectionEnable"
        )
        new_object_params["protectedManagementFrame"] = self.new_object.get(
            "protectedManagementFrame"
        )
        new_object_params["multiPSKSettings"] = self.new_object.get("multiPSKSettings")
        new_object_params["clientRateLimit"] = self.new_object.get("clientRateLimit")
        new_object_params["rsnCipherSuiteGcmp256"] = self.new_object.get(
            "rsnCipherSuiteGcmp256"
        )
        new_object_params["rsnCipherSuiteCcmp256"] = self.new_object.get(
            "rsnCipherSuiteCcmp256"
        )
        new_object_params["rsnCipherSuiteGcmp128"] = self.new_object.get(
            "rsnCipherSuiteGcmp128"
        )
        new_object_params["rsnCipherSuiteCcmp128"] = self.new_object.get(
            "rsnCipherSuiteCcmp128"
        )
        new_object_params["ghz6PolicyClientSteering"] = self.new_object.get(
            "ghz6PolicyClientSteering"
        )
        new_object_params["isAuthKey8021x"] = self.new_object.get("isAuthKey8021x")
        new_object_params["isAuthKey8021xPlusFT"] = self.new_object.get(
            "isAuthKey8021xPlusFT"
        )
        new_object_params["isAuthKey8021x_SHA256"] = self.new_object.get(
            "isAuthKey8021x_SHA256"
        )
        new_object_params["isAuthKeySae"] = self.new_object.get("isAuthKeySae")
        new_object_params["isAuthKeySaePlusFT"] = self.new_object.get(
            "isAuthKeySaePlusFT"
        )
        new_object_params["isAuthKeyPSK"] = self.new_object.get("isAuthKeyPSK")
        new_object_params["isAuthKeyPSKPlusFT"] = self.new_object.get(
            "isAuthKeyPSKPlusFT"
        )
        new_object_params["isAuthKeyOWE"] = self.new_object.get("isAuthKeyOWE")
        new_object_params["isAuthKeyEasyPSK"] = self.new_object.get("isAuthKeyEasyPSK")
        new_object_params["isAuthKeyPSKSHA256"] = self.new_object.get(
            "isAuthKeyPSKSHA256"
        )
        new_object_params["openSsid"] = self.new_object.get("openSsid")
        new_object_params["wlanBandSelectEnable"] = self.new_object.get(
            "wlanBandSelectEnable"
        )
        new_object_params["isEnabled"] = self.new_object.get("isEnabled")
        new_object_params["authServers"] = self.new_object.get("authServers")
        new_object_params["acctServers"] = self.new_object.get("acctServers")
        new_object_params["egressQos"] = self.new_object.get("egressQos")
        new_object_params["ingressQos"] = self.new_object.get("ingressQos")
        new_object_params["wlanType"] = self.new_object.get("wlanType")
        new_object_params["l3AuthType"] = self.new_object.get("l3AuthType")
        new_object_params["authServer"] = self.new_object.get("authServer")
        new_object_params["externalAuthIpAddress"] = self.new_object.get(
            "externalAuthIpAddress"
        )
        new_object_params["webPassthrough"] = self.new_object.get("webPassthrough")
        new_object_params["sleepingClientEnable"] = self.new_object.get(
            "sleepingClientEnable"
        )
        new_object_params["sleepingClientTimeout"] = self.new_object.get(
            "sleepingClientTimeout"
        )
        new_object_params["aclName"] = self.new_object.get("aclName")
        new_object_params["isPosturingEnabled"] = self.new_object.get(
            "isPosturingEnabled"
        )
        new_object_params["isAuthKeySuiteB1x"] = self.new_object.get(
            "isAuthKeySuiteB1x"
        )
        new_object_params["isAuthKeySuiteB1921x"] = self.new_object.get(
            "isAuthKeySuiteB1921x"
        )
        new_object_params["isAuthKeySaeExt"] = self.new_object.get("isAuthKeySaeExt")
        new_object_params["isAuthKeySaeExtPlusFT"] = self.new_object.get(
            "isAuthKeySaeExtPlusFT"
        )
        new_object_params["isApBeaconProtectionEnabled"] = self.new_object.get(
            "isApBeaconProtectionEnabled"
        )
        new_object_params["ghz24Policy"] = self.new_object.get("ghz24Policy")
        new_object_params["cckmTsfTolerance"] = self.new_object.get("cckmTsfTolerance")
        new_object_params["isCckmEnabled"] = self.new_object.get("isCckmEnabled")
        new_object_params["isHex"] = self.new_object.get("isHex")
        new_object_params["isRandomMacFilterEnabled"] = self.new_object.get(
            "isRandomMacFilterEnabled"
        )
        new_object_params["fastTransitionOverTheDistributedSystemEnable"] = (
            self.new_object.get("fastTransitionOverTheDistributedSystemEnable")
        )
        new_object_params["isRadiusProfilingEnabled"] = self.new_object.get(
            "isRadiusProfilingEnabled"
        )
        new_object_params["policyProfileName"] = self.new_object.get(
            "policyProfileName"
        )
        new_object_params["siteId"] = self.new_object.get("siteId")
        return new_object_params

    def delete_by_id_params(self):
        new_object_params = {}
        new_object_params["remove_override_in_hierarchy"] = self.new_object.get(
            "remove_override_in_hierarchy"
        )
        new_object_params["site_id"] = self.new_object.get("site_id")
        new_object_params["id"] = self.new_object.get("id")
        return new_object_params

    def update_by_id_params(self):
        new_object_params = {}
        new_object_params["ssid"] = self.new_object.get("ssid")
        new_object_params["authType"] = self.new_object.get("authType")
        new_object_params["passphrase"] = self.new_object.get("passphrase")
        new_object_params["isFastLaneEnabled"] = self.new_object.get(
            "isFastLaneEnabled"
        )
        new_object_params["isMacFilteringEnabled"] = self.new_object.get(
            "isMacFilteringEnabled"
        )
        new_object_params["ssidRadioType"] = self.new_object.get("ssidRadioType")
        new_object_params["isBroadcastSSID"] = self.new_object.get("isBroadcastSSID")
        new_object_params["fastTransition"] = self.new_object.get("fastTransition")
        new_object_params["sessionTimeOutEnable"] = self.new_object.get(
            "sessionTimeOutEnable"
        )
        new_object_params["sessionTimeOut"] = self.new_object.get("sessionTimeOut")
        new_object_params["clientExclusionEnable"] = self.new_object.get(
            "clientExclusionEnable"
        )
        new_object_params["clientExclusionTimeout"] = self.new_object.get(
            "clientExclusionTimeout"
        )
        new_object_params["basicServiceSetMaxIdleEnable"] = self.new_object.get(
            "basicServiceSetMaxIdleEnable"
        )
        new_object_params["basicServiceSetClientIdleTimeout"] = self.new_object.get(
            "basicServiceSetClientIdleTimeout"
        )
        new_object_params["directedMulticastServiceEnable"] = self.new_object.get(
            "directedMulticastServiceEnable"
        )
        new_object_params["neighborListEnable"] = self.new_object.get(
            "neighborListEnable"
        )
        new_object_params["managementFrameProtectionClientprotection"] = (
            self.new_object.get("managementFrameProtectionClientprotection")
        )
        new_object_params["nasOptions"] = self.new_object.get("nasOptions")
        new_object_params["profileName"] = self.new_object.get("profileName")
        new_object_params["aaaOverride"] = self.new_object.get("aaaOverride")
        new_object_params["coverageHoleDetectionEnable"] = self.new_object.get(
            "coverageHoleDetectionEnable"
        )
        new_object_params["protectedManagementFrame"] = self.new_object.get(
            "protectedManagementFrame"
        )
        new_object_params["multiPSKSettings"] = self.new_object.get("multiPSKSettings")
        new_object_params["clientRateLimit"] = self.new_object.get("clientRateLimit")
        new_object_params["rsnCipherSuiteGcmp256"] = self.new_object.get(
            "rsnCipherSuiteGcmp256"
        )
        new_object_params["rsnCipherSuiteCcmp256"] = self.new_object.get(
            "rsnCipherSuiteCcmp256"
        )
        new_object_params["rsnCipherSuiteGcmp128"] = self.new_object.get(
            "rsnCipherSuiteGcmp128"
        )
        new_object_params["rsnCipherSuiteCcmp128"] = self.new_object.get(
            "rsnCipherSuiteCcmp128"
        )
        new_object_params["ghz6PolicyClientSteering"] = self.new_object.get(
            "ghz6PolicyClientSteering"
        )
        new_object_params["isAuthKey8021x"] = self.new_object.get("isAuthKey8021x")
        new_object_params["isAuthKey8021xPlusFT"] = self.new_object.get(
            "isAuthKey8021xPlusFT"
        )
        new_object_params["isAuthKey8021x_SHA256"] = self.new_object.get(
            "isAuthKey8021x_SHA256"
        )
        new_object_params["isAuthKeySae"] = self.new_object.get("isAuthKeySae")
        new_object_params["isAuthKeySaePlusFT"] = self.new_object.get(
            "isAuthKeySaePlusFT"
        )
        new_object_params["isAuthKeyPSK"] = self.new_object.get("isAuthKeyPSK")
        new_object_params["isAuthKeyPSKPlusFT"] = self.new_object.get(
            "isAuthKeyPSKPlusFT"
        )
        new_object_params["isAuthKeyOWE"] = self.new_object.get("isAuthKeyOWE")
        new_object_params["isAuthKeyEasyPSK"] = self.new_object.get("isAuthKeyEasyPSK")
        new_object_params["isAuthKeyPSKSHA256"] = self.new_object.get(
            "isAuthKeyPSKSHA256"
        )
        new_object_params["openSsid"] = self.new_object.get("openSsid")
        new_object_params["wlanBandSelectEnable"] = self.new_object.get(
            "wlanBandSelectEnable"
        )
        new_object_params["isEnabled"] = self.new_object.get("isEnabled")
        new_object_params["authServers"] = self.new_object.get("authServers")
        new_object_params["acctServers"] = self.new_object.get("acctServers")
        new_object_params["egressQos"] = self.new_object.get("egressQos")
        new_object_params["ingressQos"] = self.new_object.get("ingressQos")
        new_object_params["wlanType"] = self.new_object.get("wlanType")
        new_object_params["l3AuthType"] = self.new_object.get("l3AuthType")
        new_object_params["authServer"] = self.new_object.get("authServer")
        new_object_params["externalAuthIpAddress"] = self.new_object.get(
            "externalAuthIpAddress"
        )
        new_object_params["webPassthrough"] = self.new_object.get("webPassthrough")
        new_object_params["sleepingClientEnable"] = self.new_object.get(
            "sleepingClientEnable"
        )
        new_object_params["sleepingClientTimeout"] = self.new_object.get(
            "sleepingClientTimeout"
        )
        new_object_params["aclName"] = self.new_object.get("aclName")
        new_object_params["isPosturingEnabled"] = self.new_object.get(
            "isPosturingEnabled"
        )
        new_object_params["isAuthKeySuiteB1x"] = self.new_object.get(
            "isAuthKeySuiteB1x"
        )
        new_object_params["isAuthKeySuiteB1921x"] = self.new_object.get(
            "isAuthKeySuiteB1921x"
        )
        new_object_params["isAuthKeySaeExt"] = self.new_object.get("isAuthKeySaeExt")
        new_object_params["isAuthKeySaeExtPlusFT"] = self.new_object.get(
            "isAuthKeySaeExtPlusFT"
        )
        new_object_params["isApBeaconProtectionEnabled"] = self.new_object.get(
            "isApBeaconProtectionEnabled"
        )
        new_object_params["ghz24Policy"] = self.new_object.get("ghz24Policy")
        new_object_params["cckmTsfTolerance"] = self.new_object.get("cckmTsfTolerance")
        new_object_params["isCckmEnabled"] = self.new_object.get("isCckmEnabled")
        new_object_params["isHex"] = self.new_object.get("isHex")
        new_object_params["isRandomMacFilterEnabled"] = self.new_object.get(
            "isRandomMacFilterEnabled"
        )
        new_object_params["fastTransitionOverTheDistributedSystemEnable"] = (
            self.new_object.get("fastTransitionOverTheDistributedSystemEnable")
        )
        new_object_params["isRadiusProfilingEnabled"] = self.new_object.get(
            "isRadiusProfilingEnabled"
        )
        new_object_params["policyProfileName"] = self.new_object.get(
            "policyProfileName"
        )
        new_object_params["siteId"] = self.new_object.get("siteId")
        new_object_params["id"] = self.new_object.get("id")
        return new_object_params

    def get_object_by_name(self, name):
        result = None
        # NOTE: Does not have a get by name method or it is in another action
        try:
            items = self.dnac.exec(
                family="wireless",
                function="get_ssid_by_site",
                params=self.get_all_params(name=name),
            )
            if isinstance(items, dict):
                if "response" in items:
                    items = items.get("response")
            result = get_dict_result(items, "name", name)
        except Exception:
            result = None
        return result

    def get_object_by_id(self, id):
        result = None
        try:
            items = self.dnac.exec(
                family="wireless", function="get_ssid_by_id", params={"id": id}
            )
            if isinstance(items, dict):
                if "response" in items:
                    items = items.get("response")
            result = get_dict_result(items, "id", id)
        except Exception:
            result = None
        return result

    def exists(self):
        id_exists = False
        name_exists = False
        prev_obj = None
        o_id = self.new_object.get("id")
        name = self.new_object.get("name")
        if o_id:
            prev_obj = self.get_object_by_id(o_id)
            id_exists = prev_obj is not None and isinstance(prev_obj, dict)
        if not id_exists and name:
            prev_obj = self.get_object_by_name(name)
            name_exists = prev_obj is not None and isinstance(prev_obj, dict)
        if name_exists:
            _id = prev_obj.get("id")
            if id_exists and name_exists and o_id != _id:
                raise InconsistentParameters(
                    "The 'id' and 'name' params don't refer to the same object"
                )
            if _id:
                self.new_object.update(dict(id=_id))
            if _id:
                prev_obj = self.get_object_by_id(_id)
        it_exists = prev_obj is not None and isinstance(prev_obj, dict)
        return (it_exists, prev_obj)

    def requires_update(self, current_obj):
        requested_obj = self.new_object

        obj_params = [
            ("ssid", "ssid"),
            ("authType", "authType"),
            ("passphrase", "passphrase"),
            ("isFastLaneEnabled", "isFastLaneEnabled"),
            ("isMacFilteringEnabled", "isMacFilteringEnabled"),
            ("ssidRadioType", "ssidRadioType"),
            ("isBroadcastSSID", "isBroadcastSSID"),
            ("fastTransition", "fastTransition"),
            ("sessionTimeOutEnable", "sessionTimeOutEnable"),
            ("sessionTimeOut", "sessionTimeOut"),
            ("clientExclusionEnable", "clientExclusionEnable"),
            ("clientExclusionTimeout", "clientExclusionTimeout"),
            ("basicServiceSetMaxIdleEnable", "basicServiceSetMaxIdleEnable"),
            ("basicServiceSetClientIdleTimeout", "basicServiceSetClientIdleTimeout"),
            ("directedMulticastServiceEnable", "directedMulticastServiceEnable"),
            ("neighborListEnable", "neighborListEnable"),
            (
                "managementFrameProtectionClientprotection",
                "managementFrameProtectionClientprotection",
            ),
            ("nasOptions", "nasOptions"),
            ("profileName", "profileName"),
            ("aaaOverride", "aaaOverride"),
            ("coverageHoleDetectionEnable", "coverageHoleDetectionEnable"),
            ("protectedManagementFrame", "protectedManagementFrame"),
            ("multiPSKSettings", "multiPSKSettings"),
            ("clientRateLimit", "clientRateLimit"),
            ("rsnCipherSuiteGcmp256", "rsnCipherSuiteGcmp256"),
            ("rsnCipherSuiteCcmp256", "rsnCipherSuiteCcmp256"),
            ("rsnCipherSuiteGcmp128", "rsnCipherSuiteGcmp128"),
            ("rsnCipherSuiteCcmp128", "rsnCipherSuiteCcmp128"),
            ("ghz6PolicyClientSteering", "ghz6PolicyClientSteering"),
            ("isAuthKey8021x", "isAuthKey8021x"),
            ("isAuthKey8021xPlusFT", "isAuthKey8021xPlusFT"),
            ("isAuthKey8021x_SHA256", "isAuthKey8021x_SHA256"),
            ("isAuthKeySae", "isAuthKeySae"),
            ("isAuthKeySaePlusFT", "isAuthKeySaePlusFT"),
            ("isAuthKeyPSK", "isAuthKeyPSK"),
            ("isAuthKeyPSKPlusFT", "isAuthKeyPSKPlusFT"),
            ("isAuthKeyOWE", "isAuthKeyOWE"),
            ("isAuthKeyEasyPSK", "isAuthKeyEasyPSK"),
            ("isAuthKeyPSKSHA256", "isAuthKeyPSKSHA256"),
            ("openSsid", "openSsid"),
            ("wlanBandSelectEnable", "wlanBandSelectEnable"),
            ("isEnabled", "isEnabled"),
            ("authServers", "authServers"),
            ("acctServers", "acctServers"),
            ("egressQos", "egressQos"),
            ("ingressQos", "ingressQos"),
            ("wlanType", "wlanType"),
            ("l3AuthType", "l3AuthType"),
            ("authServer", "authServer"),
            ("externalAuthIpAddress", "externalAuthIpAddress"),
            ("webPassthrough", "webPassthrough"),
            ("sleepingClientEnable", "sleepingClientEnable"),
            ("sleepingClientTimeout", "sleepingClientTimeout"),
            ("aclName", "aclName"),
            ("isPosturingEnabled", "isPosturingEnabled"),
            ("isAuthKeySuiteB1x", "isAuthKeySuiteB1x"),
            ("isAuthKeySuiteB1921x", "isAuthKeySuiteB1921x"),
            ("isAuthKeySaeExt", "isAuthKeySaeExt"),
            ("isAuthKeySaeExtPlusFT", "isAuthKeySaeExtPlusFT"),
            ("isApBeaconProtectionEnabled", "isApBeaconProtectionEnabled"),
            ("ghz24Policy", "ghz24Policy"),
            ("cckmTsfTolerance", "cckmTsfTolerance"),
            ("isCckmEnabled", "isCckmEnabled"),
            ("isHex", "isHex"),
            ("isRandomMacFilterEnabled", "isRandomMacFilterEnabled"),
            (
                "fastTransitionOverTheDistributedSystemEnable",
                "fastTransitionOverTheDistributedSystemEnable",
            ),
            ("isRadiusProfilingEnabled", "isRadiusProfilingEnabled"),
            ("policyProfileName", "policyProfileName"),
            ("siteId", "site_id"),
            ("id", "id"),
            ("removeOverrideInHierarchy", "remove_override_in_hierarchy"),
        ]
        # Method 1. Params present in request (Ansible) obj are the same as the current (DNAC) params
        # If any does not have eq params, it requires update
        return any(
            not dnac_compare_equality(
                current_obj.get(dnac_param), requested_obj.get(ansible_param)
            )
            for (dnac_param, ansible_param) in obj_params
        )

    def create(self):
        result = self.dnac.exec(
            family="wireless",
            function="create_ssid",
            params=self.create_params(),
            op_modifies=True,
        )
        return result

    def update(self):
        id = self.new_object.get("id")
        name = self.new_object.get("name")
        result = None
        if not id:
            prev_obj_name = self.get_object_by_name(name)
            id_ = None
            if prev_obj_name:
                id_ = prev_obj_name.get("id")
            if id_:
                self.new_object.update(dict(id=id_))
        result = self.dnac.exec(
            family="wireless",
            function="update_ssid",
            params=self.update_by_id_params(),
            op_modifies=True,
        )
        return result

    def delete(self):
        id = self.new_object.get("id")
        name = self.new_object.get("name")
        result = None
        if not id:
            prev_obj_name = self.get_object_by_name(name)
            id_ = None
            if prev_obj_name:
                id_ = prev_obj_name.get("id")
            if id_:
                self.new_object.update(dict(id=id_))
        result = self.dnac.exec(
            family="wireless",
            function="delete_ssid",
            params=self.delete_by_id_params(),
        )
        return result


class ActionModule(ActionBase):
    def __init__(self, *args, **kwargs):
        if not ANSIBLE_UTILS_IS_INSTALLED:
            raise AnsibleActionFail(
                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
            )
        super(ActionModule, self).__init__(*args, **kwargs)
        self._supports_async = False
        self._supports_check_mode = False
        self._result = None

    # Checks the supplied parameters against the argument spec for this module
    def _check_argspec(self):
        aav = AnsibleArgSpecValidator(
            data=self._task.args,
            schema=dict(argument_spec=argument_spec),
            schema_format="argspec",
            schema_conditionals=dict(
                required_if=required_if,
                required_one_of=required_one_of,
                mutually_exclusive=mutually_exclusive,
                required_together=required_together,
            ),
            name=self._task.action,
        )
        valid, errors, self._task.args = aav.validate()
        if not valid:
            raise AnsibleActionFail(errors)

    def run(self, tmp=None, task_vars=None):
        self._task.diff = False
        self._result = super(ActionModule, self).run(tmp, task_vars)
        self._result["changed"] = False
        self._check_argspec()

        dnac = DNACSDK(self._task.args)
        obj = SitesWirelessSettingsSsids(self._task.args, dnac)

        state = self._task.args.get("state")

        response = None

        if state == "present":
            (obj_exists, prev_obj) = obj.exists()
            if obj_exists:
                if obj.requires_update(prev_obj):
                    response = obj.update()
                    dnac.object_updated()
                else:
                    response = prev_obj
                    dnac.object_already_present()
            else:
                response = obj.create()
                dnac.object_created()

        elif state == "absent":
            (obj_exists, prev_obj) = obj.exists()
            if obj_exists:
                response = obj.delete()
                dnac.object_deleted()
            else:
                dnac.object_already_absent()

        self._result.update(dict(dnac_response=response))
        self._result.update(dnac.exit_json())
        return self._result



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_applications_count_info
short_description: Information module for Network Applications
  Count
description:
  - Get all Network Applications Count. - > Retrieves
    the number of network applications by applying basic
    filtering. If startTime and endTime are not provided,
    the API defaults to the last 24 hours. `siteId`
    is mandatory. `siteId` must be a site UUID of a
    building. For detailed information about the usage
    of the API, please refer to the Open API specification
    document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-NetworkApplications-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  siteId:
    description:
      - >
        SiteId query parameter. The site UUID without
        the top level hierarchy. `siteId` is mandatory.
        `siteId` must be a site UUID of a building.
        (Ex."buildingUuid") Examples `siteId=buildingUuid`
        (single siteId requested) `siteId=buildingUuid1&siteId=buildingUuid2`
        (multiple siteId requested).
    type: str
  ssid:
    description:
      - >
        Ssid query parameter. In the context of a network
        application, SSID refers to the name of the
        wireless network to which the client connects.
        Examples `ssid=Alpha` (single ssid requested)
        `ssid=Alpha&ssid=Guest` (multiple ssid requested).
    type: str
  applicationName:
    description:
      - >
        ApplicationName query parameter. Name of the
        application for which the experience data is
        intended. Examples `applicationName=webex` (single
        applicationName requested) `applicationName=webex&applicationName=teams`
        (multiple applicationName requested).
    type: str
  businessRelevance:
    description:
      - >
        BusinessRelevance query parameter. The application
        can be chosen to be categorized as business-relevant,
        irrelevant, or default (neutral). By doing so,
        the assurance application prioritizes the monitoring
        and analysis of business-relevant data, ensuring
        critical insights are captured. Applications
        marked as irrelevant or default are selectively
        excluded from certain data sets, streamlining
        focus on what's most important for business
        outcomes.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Applications
      RetrievesTheTotalCountOfNetworkApplicationsByApplyingBasicFiltering
    description: Complete reference of the RetrievesTheTotalCountOfNetworkApplicationsByApplyingBasicFiltering
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-total-count-of-network-applications-by-applying-basic-filtering
notes:
  - SDK Method used are
    applications.Applications.retrieves_the_total_count_of_network_applications_by_applying_basic_filtering,
  - Paths used are
    get /dna/data/api/v1/networkApplications/count,
"""

EXAMPLES = r"""
---
- name: Get all Network Applications Count
  cisco.dnac.network_applications_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    siteId: string
    ssid: string
    applicationName: string
    businessRelevance: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: templates_template_id_network_profiles_for_sites_count_info
short_description: Information module for Templates
  Template Id Network Profiles For Sites Count
description:
  - Get all Templates Template Id Network Profiles For
    Sites Count.
  - Retrieves the count of network profiles that a CLI
    template has been attached to by the template ID.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  templateId:
    description:
      - TemplateId path parameter. The `id` of the template,
        retrievable from `GET /intent/api/v1/templates`.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Configuration
      Templates RetrieveCountOfNetworkProfilesAttachedToACLITemplate
    description: Complete reference of the RetrieveCountOfNetworkProfilesAttachedToACLITemplate
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-count-of-network-profiles-attached-to-acli-template
notes:
  - SDK Method used are
    configuration_templates.ConfigurationTemplates.retrieve_count_of_network_profiles_attached_to_acl_i_template,
  - Paths used are
    get /dna/intent/api/v1/templates/{templateId}/networkProfilesForSites/count,
"""

EXAMPLES = r"""
---
- name: Get all Templates Template Id Network Profiles
    For Sites Count
  cisco.dnac.templates_template_id_network_profiles_for_sites_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    templateId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "count": 0
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: organizations_wireless_controller_devices_interfaces_l3_usage_history_by_interval_info
short_description: Information module for organizations _wireless _controller _devices _interfaces l3 _usage _history _by _interval
description:
  - Get all organizations _wireless _controller _devices _interfaces l3 _usage _history _by _interval.
  - List wireless LAN controller layer 3 interfaces history usage in an organization.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
  - cisco.meraki.module_info_pagination
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  organizationId:
    description:
      - OrganizationId path parameter. Organization ID.
    type: str
  serials:
    description:
      - >
        Serials query parameter. Optional parameter to filter wireless LAN controller by its cloud ID. This filter uses multiple exact matches.
    elements: str
    type: list
  t0:
    description:
      - T0 query parameter. The beginning of the timespan for the data. The maximum lookback period is 31 days from today.
    type: str
  t1:
    description:
      - T1 query parameter. The end of the timespan for the data. T1 can be a maximum of 31 days after t0.
    type: str
  timespan:
    description:
      - >
        Timespan query parameter. The timespan for which the information will be fetched. If specifying timespan, do not specify parameters t0
        and t1. The value must be in seconds and be less than or equal to 31 days. The default is 7 days.
    type: float
  perPage:
    description:
      - PerPage query parameter. The number of entries per page returned. Acceptable range is 3 - 1000. Default is 1000.
    type: int
  startingAfter:
    description:
      - >
        StartingAfter query parameter. A token used by the server to indicate the start of the page. Often this is a timestamp or an ID but it
        is not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page
        in the HTTP Link header should define it.
    type: str
  endingBefore:
    description:
      - >
        EndingBefore query parameter. A token used by the server to indicate the end of the page. Often this is a timestamp or an ID but it is
        not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page in
        the HTTP Link header should define it.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for wirelessController getOrganizationWirelessControllerDevicesInterfacesL3UsageHistoryByInterval
    description: Complete reference of the getOrganizationWirelessControllerDevicesInterfacesL3UsageHistoryByInterval API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-organization-wireless-controller-devices-interfaces-l3-usage-history-by-interval
notes:
  - SDK Method used are
    wireless_controller.WirelessController.get_organization_wireless_controller_devices_interfaces_l3_usage_history_by_interval,
  - Paths used are
    get /organizations/{organizationId}/wirelessController/devices/interfaces/l3/usage/history/byInterval,
"""

EXAMPLES = r"""
- name: Get all organizations _wireless _controller _devices _interfaces l3 _usage _history _by _interval
  cisco.meraki.organizations_wireless_controller_devices_interfaces_l3_usage_history_by_interval_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    serials: []
    t0: string
    t1: string
    timespan: 0
    perPage: 0
    startingAfter: string
    endingBefore: string
    organizationId: string
    total_pages: -1
    direction: next
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample: >
    {
      "items": [
        {
          "readings": [
            {
              "mac": "string",
              "name": "string",
              "recv": 0,
              "send": 0
            }
          ],
          "serial": "string"
        }
      ],
      "meta": {
        "counts": {
          "items": {
            "remaining": 0,
            "total": 0
          }
        }
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_access_points_factory_reset_request_provision
short_description: Resource module for Wireless Access
  Points Factory Reset Request Provision
description:
  - Manage operation create of the resource Wireless
    Access Points Factory Reset Request Provision. -
    > This API is used to factory reset Access Points.
    It is supported for maximum 100 Access Points per
    request. Factory reset clears all configurations
    from the Access Points. After factory reset the
    Access Point may become unreachable from the currently
    associated Wireless Controller and may or may not
    join back the same controller.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  apMacAddresses:
    description: List of Access Point's Ethernet MAC
      addresses, set maximum 100 ethernet MAC addresses
      per request.
    elements: str
    type: list
  keepStaticIPConfig:
    description: Set the value of keepStaticIPConfig
      to false, to clear all configurations from Access
      Points and set the value of keepStaticIPConfig
      to true, to clear all configurations from Access
      Points without clearing static IP configuration.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      FactoryResetAccessPoints
    description: Complete reference of the FactoryResetAccessPoints
      API.
    link: https://developer.cisco.com/docs/dna-center/#!factory-reset-access-points
notes:
  - SDK Method used are
    wireless.Wireless.factory_reset_access_points,
  - Paths used are
    post /dna/intent/api/v1/wirelessAccessPoints/factoryResetRequest/provision,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wireless_access_points_factory_reset_request_provision:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    apMacAddresses:
      - string
    keepStaticIPConfig: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: endpoint_analytics_profiling_rules_bulk
short_description: Resource module for Endpoint Analytics
  Profiling-Rules Bulk
description:
  - Manage operation create of the resource Endpoint
    Analytics Profiling-Rules Bulk. - > This API imports
    the given list of profiling rules. For each record,
    1- If 'ruleType' for a record is not 'Custom Rule',
    then it is rejected. 2- If 'ruleId' is provided
    in the input record,.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  profilingRules:
    description: Endpoint Analytics Profiling Rules
      Bulk's profilingRules.
    elements: dict
    suboptions:
      clusterId:
        description: Unique identifier for ML cluster.
          Only applicable for 'ML Rule'.
        type: str
      conditionGroups:
        description: Endpoint Analytics Profiling Rules
          Bulk's conditionGroups.
        suboptions:
          condition:
            description: Endpoint Analytics Profiling
              Rules Bulk's condition.
            suboptions:
              attribute:
                description: Endpoint Analytics Profiling
                  Rules Bulk's attribute.
                type: str
              attributeDictionary:
                description: Endpoint Analytics Profiling
                  Rules Bulk's attributeDictionary.
                type: str
              operator:
                description: Endpoint Analytics Profiling
                  Rules Bulk's operator.
                type: str
              value:
                description: Endpoint Analytics Profiling
                  Rules Bulk's value.
                type: str
            type: dict
          conditionGroup:
            description: Endpoint Analytics Profiling
              Rules Bulk's conditionGroup.
            elements: dict
            type: list
          operator:
            description: Endpoint Analytics Profiling
              Rules Bulk's operator.
            type: str
          type:
            description: Endpoint Analytics Profiling
              Rules Bulk's type.
            type: str
        type: dict
      isDeleted:
        description: Flag to indicate whether the rule
          was deleted.
        type: bool
      lastModifiedBy:
        description: User that last modified the rule.
          It is read-only, and is ignored if provided
          as part of input request.
        type: str
      lastModifiedOn:
        description: Timestamp (in epoch milliseconds)
          of last modification. It is read-only, and
          is ignored if provided as part of input request.
        type: int
      pluginId:
        description: Plugin for the rule. Only applicable
          for 'Cisco Default' rules.
        type: str
      rejected:
        description: Flag to indicate whether rule has
          been rejected by user or not. Only applicable
          for 'ML Rule'.
        type: bool
      result:
        description: Endpoint Analytics Profiling Rules
          Bulk's result.
        suboptions:
          deviceType:
            description: List of device types determined
              by the current rule.
            elements: str
            type: list
          hardwareManufacturer:
            description: List of hardware manufacturers
              determined by the current rule.
            elements: str
            type: list
          hardwareModel:
            description: List of hardware models determined
              by the current rule.
            elements: str
            type: list
          operatingSystem:
            description: List of operating systems determined
              by the current rule.
            elements: str
            type: list
        type: dict
      ruleId:
        description: Unique identifier for the rule.
          This is normally generated by the system,
          and client does not need to provide it for
          rules that need to be newly created.
        type: str
      ruleName:
        description: Human readable name for the rule.
        type: str
      rulePriority:
        description: Priority for the rule.
        type: int
      ruleType:
        description: Type of the rule.
        type: str
      ruleVersion:
        description: Version of the rule.
        type: int
      sourcePriority:
        description: Source priority for the rule.
        type: int
      usedAttributes:
        description: List of attributes used in the
          rule. Only applicable for 'Cisco Default'
          rules.
        elements: str
        type: list
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
notes:
  - SDK Method used are
    ai_endpoint_analytics.AiEndpointAnalytics.import_profiling_rules_in_bulk,
  - Paths used are
    post /dna/intent/api/v1/endpoint-analytics/profiling-rules/bulk,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.endpoint_analytics_profiling-rules_bulk:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    profilingRules:
      - clusterId: string
        conditionGroups:
          condition:
            attribute: string
            attributeDictionary: string
            operator: string
            value: string
          conditionGroup:
            - {}
          operator: string
          type: string
        isDeleted: true
        lastModifiedBy: string
        lastModifiedOn: 0
        pluginId: string
        rejected: true
        result:
          deviceType:
            - string
          hardwareManufacturer:
            - string
          hardwareModel:
            - string
          operatingSystem:
            - string
        ruleId: string
        ruleName: string
        rulePriority: 0
        ruleType: string
        ruleVersion: 0
        sourcePriority: 0
        usedAttributes:
          - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {}
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: authentication_policy_servers
short_description: Resource module for Authentication
  Policy Servers
description:
  - Manage operations create, update and delete of the
    resource Authentication Policy Servers. - > API
    to add AAA/ISE server access configuration. Protocol
    can be configured as either RADIUS OR TACACS OR
    RADIUS_TACACS. If configuring Cisco ISE server,
    after configuration, use "Cisco ISE Server Integration
    Status" Intent API to check the integration status.
    Based on integration status, if require use 'Accept
    Cisco ISE Server Certificate for Cisco ISE Server
    Integration' Intent API to accept the Cisco ISE
    certificate for Cisco ISE server integration, then
    use again "Cisco ISE Server Integration Status"
    Intent API to check the integration status.
  - API to delete AAA/ISE server access configuration.
    - > API to edit AAA/ISE server access configuration.
    After edit, use "Cisco ISE Server Integration Status"
    Intent API to check the integration status.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  accountingPort:
    description: Accounting port of RADIUS server. It
      is required for RADIUS server. The range is from
      1 to 65535. E.g. 1813.
    type: int
  authenticationPort:
    description: Authentication port of RADIUS server.
      It is required for RADIUS server. The range is
      from 1 to 65535. E.g. 1812.
    type: int
  ciscoIseDtos:
    description: Authentication Policy Servers's ciscoIseDtos.
    elements: dict
    suboptions:
      description:
        description: Description about the Cisco ISE
          server.
        type: str
      fqdn:
        description: Fully-qualified domain name of
          the Cisco ISE server. E.g. Xi-62.my.com.
        type: str
      ipAddress:
        description: IP Address of the Cisco ISE Server.
        type: str
      password:
        description: Password of the Cisco ISE server.
        type: str
      sshkey:
        description: SSH key of the Cisco ISE server.
        type: str
      subscriberName:
        description: Subscriber name of the Cisco ISE
          server. E.g. Pxgrid_client_1662589467.
        type: str
      userName:
        description: User name of the Cisco ISE server.
        type: str
    type: list
  encryptionKey:
    description: Encryption key used to encrypt shared
      secret.
    type: str
  encryptionScheme:
    description: Type of encryption scheme for additional
      security.
    type: str
  externalCiscoIseIpAddrDtos:
    description: Authentication Policy Servers's externalCiscoIseIpAddrDtos.
    elements: dict
    suboptions:
      externalCiscoIseIpAddresses:
        description: Authentication Policy Servers's
          externalCiscoIseIpAddresses.
        elements: dict
        suboptions:
          externalIpAddress:
            description: External IP Address.
            type: str
        type: list
      type:
        description: Type.
        type: str
    type: list
  id:
    description: Id path parameter. Authentication and
      Policy Server Identifier. Use 'Get Authentication
      and Policy Servers' intent API to find the identifier.
    type: str
  ipAddress:
    description: IP address of authentication and policy
      server.
    type: str
  isIseEnabled:
    description: Value true for Cisco ISE Server. Default
      value is false.
    type: bool
  messageKey:
    description: Message key used to encrypt shared
      secret.
    type: str
  port:
    description: Port of TACACS server. It is required
      for TACACS server. The range is from 1 to 65535.
    type: int
  protocol:
    description: Type of protocol for authentication
      and policy server. If already saved with RADIUS,
      can update to RADIUS_TACACS. If already saved
      with TACACS, can update to RADIUS_TACACS.
    type: str
  pxgridEnabled:
    description: Value true for enable, false for disable.
      Default value is true.
    type: bool
  retries:
    description: Number of communication retries between
      devices and authentication and policy server.
      The range is from 1 to 3.
    type: str
  role:
    description: Role of authentication and policy server.
      E.g. Primary, secondary.
    type: str
  sharedSecret:
    description: Shared secret between devices and authentication
      and policy server.
    type: str
  timeoutSeconds:
    description: Number of seconds before timing out
      between devices and authentication and policy
      server. The range is from 2 to 20.
    type: str
  useDnacCertForPxgrid:
    description: Value true to use Catalyst Center certificate
      for Pxgrid. Default value is false.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for System
      Settings AddAuthenticationAndPolicyServerAccessConfiguration
    description: Complete reference of the AddAuthenticationAndPolicyServerAccessConfiguration
      API.
    link: https://developer.cisco.com/docs/dna-center/#!add-authentication-and-policy-server-access-configuration
  - name: Cisco DNA Center documentation for System
      Settings DeleteAuthenticationAndPolicyServerAccessConfiguration
    description: Complete reference of the DeleteAuthenticationAndPolicyServerAccessConfiguration
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-authentication-and-policy-server-access-configuration
  - name: Cisco DNA Center documentation for System
      Settings EditAuthenticationAndPolicyServerAccessConfiguration
    description: Complete reference of the EditAuthenticationAndPolicyServerAccessConfiguration
      API.
    link: https://developer.cisco.com/docs/dna-center/#!edit-authentication-and-policy-server-access-configuration
notes:
  - SDK Method used are
    system_settings.SystemSettings.add_authentication_and_policy_server_access_configuration,
    system_settings.SystemSettings.delete_authentication_and_policy_server_access_configuration,
    system_settings.SystemSettings.edit_authentication_and_policy_server_access_configuration,
  - Paths used are
    post /dna/intent/api/v1/authentication-policy-servers,
    delete /dna/intent/api/v1/authentication-policy-servers/{id},
    put /dna/intent/api/v1/authentication-policy-servers/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.authentication_policy_servers:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    accountingPort: 0
    authenticationPort: 0
    ciscoIseDtos:
      - description: string
        fqdn: string
        ipAddress: string
        password: string
        sshkey: string
        subscriberName: string
        userName: string
    encryptionKey: string
    encryptionScheme: string
    externalCiscoIseIpAddrDtos:
      - externalCiscoIseIpAddresses:
          - externalIpAddress: string
        type: string
    ipAddress: string
    isIseEnabled: true
    messageKey: string
    port: 0
    protocol: string
    pxgridEnabled: true
    retries: string
    role: string
    sharedSecret: string
    timeoutSeconds: string
    useDnacCertForPxgrid: true
- name: Delete by id
  cisco.dnac.authentication_policy_servers:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.authentication_policy_servers:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    accountingPort: 0
    authenticationPort: 0
    ciscoIseDtos:
      - fqdn: string
        password: string
        sshkey: string
        userName: string
    externalCiscoIseIpAddrDtos:
      - externalCiscoIseIpAddresses:
          - externalIpAddress: string
        type: string
    id: string
    port: 0
    protocol: string
    pxgridEnabled: true
    retries: string
    timeoutSeconds: string
    useDnacCertForPxgrid: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: device_credential
short_description: Resource module for Device Credential
description:
  - Manage operations create, update and delete of the
    resource Device Credential.
  - API to create device credentials.
  - Delete device credential.
  - API to update device credentials.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Global credential
      id.
    type: str
  settings:
    description: Device Credential's settings.
    suboptions:
      cliCredential:
        description: Device Credential's cliCredential.
        elements: dict
        suboptions:
          description:
            description: Name or description for CLI
              credential.
            type: str
          enablePassword:
            description: Enable password for CLI credential.
            type: str
          password:
            description: Password for CLI credential.
            type: str
          username:
            description: User name for CLI credential.
            type: str
        type: list
      httpsRead:
        description: Device Credential's httpsRead.
        elements: dict
        suboptions:
          name:
            description: Name or description of http
              read credential.
            type: str
          password:
            description: Password for http read credential.
            type: str
          port:
            description: Port for http read credential.
            type: float
          username:
            description: User name of the http read
              credential.
            type: str
        type: list
      httpsWrite:
        description: Device Credential's httpsWrite.
        elements: dict
        suboptions:
          name:
            description: Name or description of http
              write credential.
            type: str
          password:
            description: Password for http write credential.
            type: str
          port:
            description: Port for http write credential.
            type: float
          username:
            description: User name of the http write
              credential.
            type: str
        type: list
      snmpV2cRead:
        description: Device Credential's snmpV2cRead.
        elements: dict
        suboptions:
          description:
            description: Description for snmp v2 read.
            type: str
          readCommunity:
            description: Ready community for snmp v2
              read credential.
            type: str
        type: list
      snmpV2cWrite:
        description: Device Credential's snmpV2cWrite.
        elements: dict
        suboptions:
          description:
            description: Description for snmp v2 write.
            type: str
          writeCommunity:
            description: Write community for snmp v2
              write credential.
            type: str
        type: list
      snmpV3:
        description: Device Credential's snmpV3.
        elements: dict
        suboptions:
          authPassword:
            description: Authentication password for
              snmpv3 credential.
            type: str
          authType:
            description: Authentication type for snmpv3
              credential.
            type: str
          description:
            description: Name or description for SNMPV3
              credential.
            type: str
          privacyPassword:
            description: Privacy password for snmpv3
              credential.
            type: str
          privacyType:
            description: Privacy type for snmpv3 credential.
            type: str
          snmpMode:
            description: Mode for snmpv3 credential.
            type: str
          username:
            description: User name for SNMPv3 credential.
            type: str
        type: list
    type: dict
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Network
      Settings CreateDeviceCredentials
    description: Complete reference of the CreateDeviceCredentials
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-device-credentials
  - name: Cisco DNA Center documentation for Network
      Settings DeleteDeviceCredential
    description: Complete reference of the DeleteDeviceCredential
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-device-credential
  - name: Cisco DNA Center documentation for Network
      Settings UpdateDeviceCredentials
    description: Complete reference of the UpdateDeviceCredentials
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-device-credentials
notes:
  - SDK Method used are
    network_settings.NetworkSettings.create_device_credentials,
    network_settings.NetworkSettings.delete_device_credential,
    network_settings.NetworkSettings.update_device_credentials,
  - Paths used are
    post /dna/intent/api/v1/device-credential,
    delete /dna/intent/api/v1/device-credential/{id},
    put /dna/intent/api/v1/device-credential,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.device_credential:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    settings:
      cliCredential:
        - description: string
          enablePassword: string
          password: string
          username: string
      httpsRead:
        - name: string
          password: string
          port: 0
          username: string
      httpsWrite:
        - name: string
          password: string
          port: 0
          username: string
      snmpV2cRead:
        - description: string
          readCommunity: string
      snmpV2cWrite:
        - description: string
          writeCommunity: string
      snmpV3:
        - authPassword: string
          authType: string
          description: string
          privacyPassword: string
          privacyType: string
          snmpMode: string
          username: string
- name: Update all
  cisco.dnac.device_credential:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    settings:
      cliCredential:
        description: string
        enablePassword: string
        id: string
        password: string
        username: string
      httpsRead:
        id: string
        name: string
        password: string
        port: string
        username: string
      httpsWrite:
        id: string
        name: string
        password: string
        port: string
        username: string
      snmpV2cRead:
        description: string
        id: string
        readCommunity: string
      snmpV2cWrite:
        description: string
        id: string
        writeCommunity: string
      snmpV3:
        authPassword: string
        authType: string
        description: string
        id: string
        privacyPassword: string
        privacyType: string
        snmpMode: string
        username: string
- name: Delete by id
  cisco.dnac.device_credential:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "executionId": "string",
      "executionStatusUrl": "string",
      "message": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: backups
short_description: Resource module for Backups
description:
  - Manage operation create of the resource Backups.
    - > This api is used to trigger a workflow to create
    an on demand backup. To monitor the progress and
    completion of the backup creation , please call
    `/dna/system/api/v1/backupRestoreExecutions/{id}`
    api , where id is the taskId attribute from the
    response of the curent endpoint.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  name:
    description: The backup name.
    type: str
  scope:
    description: The backup scope states whether the
      backup is with assurance or without assurance
      data.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Backup
      CreateBackup
    description: Complete reference of the CreateBackup
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-backup
notes:
  - SDK Method used are
    backup.Backup.create_backup,
  - Paths used are
    post /dna/system/api/v1/backups,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.backups:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    name: string
    scope: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {}
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wired_network_devices_id_config_features_intended_layer2_feature_info
short_description: Information module for Wired Network
  Devices Id Config Features Intended Layer2 Feature
description:
  - Get Wired Network Devices Id Config Features Intended
    Layer2 Feature by id. - > This API returns the configurations
    for an intended layer 2 feature on a wired device.
    Even after the intended configurations are deployed
    using the API /dna/intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy,
    they continue to be a part of the intended features
    on the device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Network device ID of the
        wired device to configure.
    type: str
  feature:
    description:
      - Feature path parameter. The name of the feature
        to be retrieved.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wired GetConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice
    description: Complete reference of the GetConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-configurations-for-an-intended-layer-2-feature-on-a-wired-device
notes:
  - SDK Method used are
    wired.Wired.get_configurations_for_an_intended_layer2_feature_on_a_wired_device,
  - Paths used are
    get /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2/{feature},
"""

EXAMPLES = r"""
---
- name: Get Wired Network Devices Id Config Features
    Intended Layer2 Feature by id
  cisco.dnac.wired_network_devices_id_config_features_intended_layer2_feature_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    feature: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "cdpGlobalConfig": {
        "items": [
          [
            {
              "configType": "string",
              "timer": 0,
              "isCdpEnabled": true,
              "isLogDuplexMismatchEnabled": true,
              "isAdvertiseV2Enabled": true,
              "holdTime": 0
            }
          ]
        ]
      },
      "cdpInterfaceConfig": {
        "items": [
          [
            {
              "configType": "string",
              "interfaceName": "string",
              "isCdpEnabled": true,
              "isLogDuplexMismatchEnabled": true
            }
          ]
        ]
      },
      "dhcpSnoopingInterfaceConfig": {
        "items": [
          [
            {
              "configType": "string",
              "interfaceName": "string",
              "isTrustedInterface": true,
              "messageRateLimit": 0
            }
          ]
        ]
      },
      "dhcpSnoopingGlobalConfig": {
        "items": [
          [
            {
              "configType": "string",
              "isDhcpSnoopingEnabled": true,
              "databaseAgent": {
                "configType": "string",
                "agentUrl": "string",
                "timeout": 0,
                "writeDelay": 0
              },
              "isGleaningEnabled": true,
              "proxyBridgeVlans": "string",
              "dhcpSnoopingVlans": "string"
            }
          ]
        ]
      },
      "dot1xInterfaceConfig": {
        "items": [
          [
            {
              "configType": "string",
              "interfaceName": "string",
              "authenticationOrder": {
                "configType": "string",
                "items": [
                  "string"
                ]
              }
            }
          ]
        ]
      },
      "dot1xGlobalConfig": {
        "items": [
          [
            {
              "configType": "string",
              "authenticationConfigMode": "string",
              "isDot1xEnabled": true
            }
          ]
        ]
      },
      "lldpGlobalConfig": {
        "items": [
          [
            {
              "configType": "string",
              "timer": 0,
              "isLldpEnabled": true,
              "reinitializationDelay": 0,
              "holdTime": 0
            }
          ]
        ]
      },
      "lldpInterfaceConfig": {
        "items": [
          [
            {
              "configType": "string",
              "interfaceName": "string",
              "adminStatus": "string"
            }
          ]
        ]
      },
      "mabInterfaceConfig": {
        "items": [
          [
            {
              "configType": "string",
              "interfaceName": "string",
              "isMabEnabled": true
            }
          ]
        ]
      },
      "mldSnoopingGlobalConfig": {
        "items": [
          [
            {
              "configType": "string",
              "isMldSnoopingEnabled": true,
              "isSuppressListenerMessagesEnabled": true,
              "isQuerierEnabled": true,
              "querierAddress": "string",
              "querierQueryInterval": 0,
              "querierVersion": "string",
              "mldSnoopingVlanSettings": {
                "configType": "string",
                "items": [
                  {
                    "configType": "string",
                    "vlanId": 0,
                    "isMldSnoopingEnabled": true,
                    "isImmediateLeaveEnabled": true,
                    "isQuerierEnabled": true,
                    "querierAddress": "string",
                    "querierQueryInterval": 0,
                    "querierVersion": "string",
                    "mldSnoopingVlanMrouters": {
                      "configType": "string",
                      "items": [
                        {
                          "configType": "string",
                          "interfaceName": "string"
                        }
                      ]
                    }
                  }
                ]
              }
            }
          ]
        ]
      },
      "igmpSnoopingGlobalConfig": {
        "items": [
          [
            {
              "configType": "string",
              "isIgmpSnoopingEnabled": true,
              "isQuerierEnabled": true,
              "querierAddress": "string",
              "querierQueryInterval": 0,
              "querierVersion": "string",
              "igmpSnoopingVlanSettings": {
                "configType": "string",
                "items": [
                  {
                    "configType": "string",
                    "vlanId": 0,
                    "isIgmpSnoopingEnabled": true,
                    "isImmediateLeaveEnabled": true,
                    "isQuerierEnabled": true,
                    "querierAddress": "string",
                    "querierQueryInterval": 0,
                    "querierVersion": "string",
                    "igmpSnoopingVlanMrouters": {
                      "configType": "string",
                      "items": [
                        {
                          "configType": "string",
                          "interfaceName": "string"
                        }
                      ]
                    }
                  }
                ]
              }
            }
          ]
        ]
      },
      "stpGlobalConfig": {
        "items": [
          [
            {
              "configType": "string",
              "stpMode": "string",
              "isBackboneFastEnabled": true,
              "isEtherChannelGuardEnabled": true,
              "isExtendedSystemIdEnabled": true,
              "isLoggingEnabled": true,
              "isLoopGuardEnabled": true,
              "portFastMode": "string",
              "isBpduFilterEnabled": true,
              "isBpduGuardEnabled": true,
              "isUplinkFastEnabled": true,
              "transmitHoldCount": 0,
              "uplinkFastMaxUpdateRate": 0,
              "stpInstances": {
                "configType": "string",
                "items": [
                  {
                    "configType": "string",
                    "vlanId": 0,
                    "priority": 0,
                    "timers": {
                      "configType": "string",
                      "forwardDelay": 0,
                      "helloInterval": 0,
                      "maxAge": 0,
                      "isStpEnabled": true
                    }
                  }
                ]
              }
            }
          ]
        ]
      },
      "stpInterfaceConfig": {
        "items": [
          {
            "configType": "string",
            "interfaceName": "string",
            "guardMode": "string",
            "bpduFilter": "string",
            "bpduGuard": "string",
            "pathCost": 0,
            "portFastMode": "string",
            "priority": 0,
            "portVlanCostSettings": {
              "configType": "string",
              "items": [
                {
                  "configType": "string",
                  "cost": 0,
                  "vlans": "string"
                }
              ]
            },
            "portVlanPrioritySettings": {
              "configType": "string",
              "items": [
                {
                  "configType": "string",
                  "priority": 0,
                  "vlans": "string"
                }
              ]
            }
          }
        ]
      },
      "trunkInterfaceConfig": {
        "items": [
          [
            {
              "configType": "string",
              "interfaceName": "string",
              "isProtected": true,
              "isDtpNegotiationEnabled": true,
              "pruneEligibleVlans": "string"
            }
          ]
        ]
      },
      "vtpGlobalConfig": {
        "items": [
          [
            {
              "configType": "string",
              "mode": "string",
              "version": "string",
              "domainName": "string",
              "isPruningEnabled": true,
              "configurationFileName": "string",
              "sourceInterface": "string"
            }
          ]
        ]
      },
      "vtpInterfaceConfig": {
        "items": [
          [
            {
              "configType": "string",
              "interfaceName": "string",
              "isVtpEnabled": true
            }
          ]
        ]
      },
      "vlanConfig": {
        "items": [
          [
            {
              "configType": "string",
              "vlanId": 0,
              "name": "string",
              "isVlanEnabled": true
            }
          ]
        ]
      },
      "portChannelConfig": {
        "items": [
          [
            {
              "configType": "string",
              "isAutoEnabled": true,
              "loadBalancingMethod": "string",
              "lacpSystemPriority": 0,
              "portchannels": {
                "configType": "string",
                "items": [
                  {
                    "AnyOf": {
                      "EtherchannelConfig": {
                        "configType": "string",
                        "name": "string",
                        "minLinks": 0,
                        "memberPorts": {
                          "configType": "string",
                          "items": [
                            {
                              "configType": "string",
                              "interfaceName": "string",
                              "mode": "string"
                            }
                          ]
                        }
                      },
                      "LacpPortchannelConfig": {
                        "configType": "string",
                        "name": "string",
                        "minLinks": 0,
                        "memberPorts": {
                          "configType": "string",
                          "items": [
                            {
                              "configType": "string",
                              "interfaceName": "string",
                              "mode": "string",
                              "portPriority": 0,
                              "rate": 0
                            }
                          ]
                        }
                      },
                      "PagpPortchannelConfig": {
                        "configType": "string",
                        "name": "string",
                        "minLinks": 0,
                        "memberPorts": {
                          "configType": "string",
                          "items": [
                            {
                              "configType": "string",
                              "interfaceName": "string",
                              "mode": "string",
                              "portPriority": 0,
                              "learnMethod": "string"
                            }
                          ]
                        }
                      }
                    }
                  }
                ]
              }
            }
          ]
        ]
      },
      "switchportInterfaceConfig": {
        "items": [
          [
            {
              "configType": "string",
              "interfaceName": "string",
              "description": "string",
              "mode": "string",
              "accessVlan": 0,
              "voiceVlan": 0,
              "adminStatus": "string",
              "trunkAllowedVlans": "string",
              "nativeVlan": 0
            }
          ]
        ]
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: floors_floor_id_planned_access_point_positions_bulk_change
short_description: Resource module for Floors Floor
  Id Planned Access Point Positions Bulk Change
description:
  - Manage operation create of the resource Floors Floor
    Id Planned Access Point Positions Bulk Change.
  - Edit Planned Access Points Positions on the map.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  floorId:
    description: FloorId path parameter. Floor Id.
    type: str
  payload:
    description: Floors Floor Id Planned Access Point
      Positions Bulk Change's payload.
    elements: dict
    suboptions:
      id:
        description: Planned Access Point Id.
        type: str
      macAddress:
        description: Planned Access Point MAC address.
        type: str
      name:
        description: Planned Access Point Name.
        type: str
      position:
        description: Floors Floor Id Planned Access
          Point Positions Bulk Change's position.
        suboptions:
          x:
            description: Planned Access Point X coordinate
              in feet.
            type: float
          y:
            description: Planned Access Point Y coordinate
              in feet.
            type: float
          z:
            description: Planned Access Point Z coordinate
              in feet.
            type: float
        type: dict
      radios:
        description: Floors Floor Id Planned Access
          Point Positions Bulk Change's radios.
        elements: dict
        suboptions:
          antenna:
            description: Floors Floor Id Planned Access
              Point Positions Bulk Change's antenna.
            suboptions:
              azimuth:
                description: Angle of the antenna, measured
                  relative to the x axis, clockwise.
                  The azimuth range is from 0 through
                  360.
                type: int
              elevation:
                description: Elevation of the antenna.
                  The elevation range is from -90 through
                  90.
                type: int
              name:
                description: Antenna type for this Planned
                  Access Point. Use `/dna/intent/api/v1/maps/supported-acc...
                  to find supported Antennas for a particualr
                  Planned Access Point type.
                type: str
            type: dict
          channel:
            description: Channel to be used by the Planned
              Access Point. In the context of a Planned
              Access Point, the channel have no bearing
              on what the real Access Point will actually
              be, they are just used for Maps visualization
              feature set.
            type: int
          id:
            description: Radio Id.
            type: str
          txPower:
            description: Transmit power for the channel
              in Decibel milliwatts (dBm). In the context
              of a Planned Access Point, the txPower
              have no bearing on what the real Access
              Point will actually be, they are just
              used for Maps visualization feature set.
            type: int
        type: list
      type:
        description: Planned Access Point type. Use
          `dna/intent/api/v1/maps/supported-access-points`
          to find the supported models.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Site Design
      EditPlannedAccessPointsPositionsV2
    description: Complete reference of the EditPlannedAccessPointsPositionsV2
      API.
    link: https://developer.cisco.com/docs/dna-center/#!edit-planned-access-points-positions-v-2
notes:
  - SDK Method used are
    site_design.SiteDesign.edit_planned_access_points_positions_v2,
  - Paths used are
    post /dna/intent/api/v2/floors/{floorId}/plannedAccessPointPositions/bulkChange,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.floors_floor_id_planned_access_point_positions_bulk_change:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    floorId: string
    payload:
      - id: string
        macAddress: string
        name: string
        position:
          x: 0
          y: 0
          z: 0
        radios:
          - antenna:
              azimuth: 0
              elevation: 0
              name: string
            channel: 0
            id: string
            txPower: 0
        type: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: endpoint_analytics_tasks_info
short_description: Information module for Endpoint Analytics
  Tasks
description:
  - Get Endpoint Analytics Tasks by id. - > Fetches
    the details of backend task. Task is typically created
    by making call to some other API that takes longer
    time to execute.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  taskId:
    description:
      - TaskId path parameter. Unique identifier for
        the task.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for AI Endpoint
      Analytics GetTaskDetails
    description: Complete reference of the GetTaskDetails
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-task-details
notes:
  - SDK Method used are
    ai_endpoint_analytics.AiEndpointAnalytics.get_task_details,
  - Paths used are
    get /dna/intent/api/v1/endpoint-analytics/tasks/{taskId},
"""

EXAMPLES = r"""
---
- name: Get Endpoint Analytics Tasks by id
  cisco.dnac.endpoint_analytics_tasks_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    taskId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "id": "string",
      "name": "string",
      "status": "string",
      "errors": [
        {
          "index": 0,
          "code": 0,
          "message": "string",
          "details": "string"
        }
      ],
      "additionalInfo": {},
      "createdBy": "string",
      "createdOn": 0,
      "lastUpdatedOn": 0
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: icap_radios_id_stats
short_description: Resource module for Icap Radios Id
  Stats
description:
  - Manage operation create of the resource Icap Radios
    Id Stats. - > Retrieves the time series statistics
    of a specific radio by applying complex filters.
    If startTime and endTime are not provided, the API
    defaults to the last 24 hours. For detailed information
    about the usage of the API, please refer to the
    Open API specification document - https //github.com/cisco-en-programmability/catalyst-
    center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-icap-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  endTime:
    description: End Time.
    type: int
  filters:
    description: Icap Radios Id Stats's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: int
    type: list
  headers:
    description: Additional headers.
    type: dict
  id:
    description: Id path parameter. Id is the composite
      key made of AP Base Ethernet macAddress and Radio
      Slot Id. Format apMac_RadioId.
    type: str
  page:
    description: Icap Radios Id Stats's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      timeSortOrder:
        description: Time Sort Order.
        type: str
    type: dict
  startTime:
    description: Start Time.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Sensors
      RetrievesSpecificRadioStatisticsOverSpecifiedPeriodOfTime
    description: Complete reference of the RetrievesSpecificRadioStatisticsOverSpecifiedPeriodOfTime
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-specific-radio-statistics-over-specified-period-of-time
notes:
  - SDK Method used are
    sensors.Sensors.retrieves_specific_radio_statistics_over_specified_period_of_time,
  - Paths used are
    post /dna/data/api/v1/icap/radios/{id}/stats,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.icap_radios_id_stats:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    endTime: 0
    filters:
      - key: string
        operator: string
        value: 0
    headers: '{{my_headers | from_json}}'
    id: string
    page:
      limit: 0
      offset: 0
      timeSortOrder: string
    startTime: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "timestamp": 0,
          "apMac": "string",
          "radioId": 0,
          "band": "string",
          "utilization": 0,
          "nonWifiUtilization": 0,
          "rxOtherBSSUtilization": 0,
          "rxInBSSUtilization": 0,
          "txUtilization": 0,
          "noiseFloor": 0,
          "channel": 0,
          "channelWidth": 0,
          "txPower": 0,
          "maxTxPower": 0,
          "txBytes": 0,
          "rxBytes": 0,
          "rxPackets": 0,
          "txPackets": 0,
          "rxMgmtPackets": 0,
          "txMgmtPackets": 0,
          "rxErrors": 0,
          "txErrors": 0
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "timeSortOrder": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: fabrics_fabric_id_switch_wireless_setting_reload
short_description: Resource module for Fabrics Fabric
  Id Switch Wireless Setting Reload
description:
  - Manage operation create of the resource Fabrics
    Fabric Id Switch Wireless Setting Reload. - > This
    API is used to reload switches after disabling wireless
    to remove the wireless-controller configuration
    on the device. When wireless is disabled on a switch,
    all wireless configurations are removed except for
    the wireless-controller configuration. To completely
    remove the wireless-controller configuration, you
    can use this API. Please note that using this API
    will cause a reload of the devices. This API should
    only be used for devices that have wireless disabled
    but still have the 'wireless-controller' configuration
    present. The reload payload can have a maximum of
    two switches as only two switches can have a wireless
    role in a fabric site.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deviceId:
    description: Network Device ID.
    type: str
  fabricId:
    description: FabricId path parameter. The 'fabricId'
      represents the Fabric ID of a particular Fabric
      Site. The 'fabricId' can be obtained using the
      api /dna/intent/api/v1/sda/fabricSites. Example
      e290f1ee-6c54-4b01-90e6-d701748f0851.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Fabric
      Wireless ReloadSwitchForWirelessControllerCleanup
    description: Complete reference of the ReloadSwitchForWirelessControllerCleanup
      API.
    link: https://developer.cisco.com/docs/dna-center/#!reload-switch-for-wireless-controller-cleanup
notes:
  - SDK Method used are
    fabric_wireless.FabricWireless.reload_switch_for_wireless_controller_cleanup,
  - Paths used are
    post /dna/intent/api/v1/sda/fabrics/{fabricId}/switchWirelessSetting/reload,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.fabrics_fabric_id_switch_wireless_setting_reload:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deviceId: string
    fabricId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_config_info
short_description: Information module for Network Device
  Config
description:
  - Get all Network Device Config . - > Returns the
    historical device configurations running configuration
    , startup configuration , vlan if applicable by
    specified criteria.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  deviceId:
    description:
      - >
        DeviceId query parameter. Comma separated device
        id for example cf35b0a1-407f-412f-b2f4-f0c3156695f9,aaa38191-0c22-4158-befd-779a09d7cec1.
        If device id is not provided it will fetch for
        all devices.
    type: str
  fileType:
    description:
      - FileType query parameter. Config File Type can
        be RUNNINGCONFIG or STARTUPCONFIG.
    type: str
  createdTime:
    description:
      - CreatedTime query parameter. Supported with
        logical filters GT,GTE,LT,LTE & BT time in milliseconds
        (epoc format).
    type: str
  createdBy:
    description:
      - >
        CreatedBy query parameter. Comma separated values
        for createdBy - SCHEDULED, USER, CONFIG_CHANGE_EVENT,
        SCHEDULED_FIRST_TIME, DR_CALL_BACK, PRE_DEPLOY.
    type: str
  offset:
    description:
      - Offset query parameter.
    type: float
  limit:
    description:
      - >
        Limit query parameter. The number of records
        to be retrieved defaults to 500 if not specified,
        with a maximum allowed limit of 500.
    type: float
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Configuration
      Archive GetConfigurationArchiveDetails
    description: Complete reference of the GetConfigurationArchiveDetails
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-configuration-archive-details
notes:
  - SDK Method used are
    configuration_archive.ConfigurationArchive.get_configuration_archive_details,
  - Paths used are
    get /dna/intent/api/v1/network-device-config,
"""

EXAMPLES = r"""
---
- name: Get all Network Device Config
  cisco.dnac.network_device_config__info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    deviceId: string
    fileType: string
    createdTime: string
    createdBy: string
    offset: 0
    limit: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "ipAddress": "string",
        "deviceId": "string",
        "versions": [
          {
            "files": [
              {
                "fileType": "string",
                "fileId": "string",
                "downloadPath": "string"
              }
            ],
            "createdBy": "string",
            "configChangeType": "string",
            "syslogConfigEventDto": [
              {
                "userName": "string",
                "deviceUuid": "string",
                "outOfBand": true,
                "configMethod": "string",
                "terminalName": "string",
                "loginIpAddress": "string",
                "processName": "string",
                "syslogTime": 0
              }
            ],
            "createdTime": 0,
            "startupRunningStatus": "string",
            "id": "string",
            "tags": [
              "string"
            ],
            "lastUpdatedTime": 0
          }
        ],
        "deviceName": "string"
      }
    ]
"""



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or
# https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type
from ansible.plugins.action import ActionBase

try:
    from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
        AnsibleArgSpecValidator,
    )
except ImportError:
    ANSIBLE_UTILS_IS_INSTALLED = False
else:
    ANSIBLE_UTILS_IS_INSTALLED = True
from ansible.errors import AnsibleActionFail
from ansible_collections.cisco.dnac.plugins.plugin_utils.dnac import (
    DNACSDK,
    dnac_argument_spec,
)

# Get common arguements specification
argument_spec = dnac_argument_spec()
# Add arguments specific for this module
argument_spec.update(
    dict(
        ssid=dict(type="str"),
        authType=dict(type="str"),
        passphrase=dict(type="str"),
        isFastLaneEnabled=dict(type="bool"),
        isMacFilteringEnabled=dict(type="bool"),
        ssidRadioType=dict(type="str"),
        isBroadcastSSID=dict(type="bool"),
        fastTransition=dict(type="str"),
        sessionTimeOutEnable=dict(type="bool"),
        sessionTimeOut=dict(type="int"),
        clientExclusionEnable=dict(type="bool"),
        clientExclusionTimeout=dict(type="int"),
        basicServiceSetMaxIdleEnable=dict(type="bool"),
        basicServiceSetClientIdleTimeout=dict(type="int"),
        directedMulticastServiceEnable=dict(type="bool"),
        neighborListEnable=dict(type="bool"),
        managementFrameProtectionClientprotection=dict(type="str"),
        nasOptions=dict(type="list"),
        profileName=dict(type="str"),
        aaaOverride=dict(type="bool"),
        coverageHoleDetectionEnable=dict(type="bool"),
        protectedManagementFrame=dict(type="str"),
        multiPSKSettings=dict(type="list"),
        clientRateLimit=dict(type="int"),
        rsnCipherSuiteGcmp256=dict(type="bool"),
        rsnCipherSuiteCcmp256=dict(type="bool"),
        rsnCipherSuiteGcmp128=dict(type="bool"),
        rsnCipherSuiteCcmp128=dict(type="bool"),
        ghz6PolicyClientSteering=dict(type="bool"),
        isAuthKey8021x=dict(type="bool"),
        isAuthKey8021xPlusFT=dict(type="bool"),
        isAuthKey8021x_SHA256=dict(type="bool"),
        isAuthKeySae=dict(type="bool"),
        isAuthKeySaePlusFT=dict(type="bool"),
        isAuthKeyPSK=dict(type="bool"),
        isAuthKeyPSKPlusFT=dict(type="bool"),
        isAuthKeyOWE=dict(type="bool"),
        isAuthKeyEasyPSK=dict(type="bool"),
        isAuthKeyPSKSHA256=dict(type="bool"),
        openSsid=dict(type="str"),
        wlanBandSelectEnable=dict(type="bool"),
        isEnabled=dict(type="bool"),
        authServers=dict(type="list"),
        acctServers=dict(type="list"),
        egressQos=dict(type="str"),
        ingressQos=dict(type="str"),
        wlanType=dict(type="str"),
        l3AuthType=dict(type="str"),
        authServer=dict(type="str"),
        externalAuthIpAddress=dict(type="str"),
        webPassthrough=dict(type="bool"),
        sleepingClientEnable=dict(type="bool"),
        sleepingClientTimeout=dict(type="int"),
        aclName=dict(type="str"),
        isPosturingEnabled=dict(type="bool"),
        isAuthKeySuiteB1x=dict(type="bool"),
        isAuthKeySuiteB1921x=dict(type="bool"),
        isAuthKeySaeExt=dict(type="bool"),
        isAuthKeySaeExtPlusFT=dict(type="bool"),
        isApBeaconProtectionEnabled=dict(type="bool"),
        ghz24Policy=dict(type="str"),
        cckmTsfTolerance=dict(type="int"),
        isCckmEnabled=dict(type="bool"),
        isHex=dict(type="bool"),
        isRandomMacFilterEnabled=dict(type="bool"),
        fastTransitionOverTheDistributedSystemEnable=dict(type="bool"),
        isRadiusProfilingEnabled=dict(type="bool"),
        policyProfileName=dict(type="str"),
        siteId=dict(type="str"),
        id=dict(type="str"),
    )
)

required_if = []
required_one_of = []
mutually_exclusive = []
required_together = []


class ActionModule(ActionBase):
    def __init__(self, *args, **kwargs):
        if not ANSIBLE_UTILS_IS_INSTALLED:
            raise AnsibleActionFail(
                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
            )
        super(ActionModule, self).__init__(*args, **kwargs)
        self._supports_async = False
        self._supports_check_mode = False
        self._result = None

    # Checks the supplied parameters against the argument spec for this module
    def _check_argspec(self):
        aav = AnsibleArgSpecValidator(
            data=self._task.args,
            schema=dict(argument_spec=argument_spec),
            schema_format="argspec",
            schema_conditionals=dict(
                required_if=required_if,
                required_one_of=required_one_of,
                mutually_exclusive=mutually_exclusive,
                required_together=required_together,
            ),
            name=self._task.action,
        )
        valid, errors, self._task.args = aav.validate()
        if not valid:
            raise AnsibleActionFail(errors)

    def get_object(self, params):
        new_object = dict(
            ssid=params.get("ssid"),
            authType=params.get("authType"),
            passphrase=params.get("passphrase"),
            isFastLaneEnabled=params.get("isFastLaneEnabled"),
            isMacFilteringEnabled=params.get("isMacFilteringEnabled"),
            ssidRadioType=params.get("ssidRadioType"),
            isBroadcastSSID=params.get("isBroadcastSSID"),
            fastTransition=params.get("fastTransition"),
            sessionTimeOutEnable=params.get("sessionTimeOutEnable"),
            sessionTimeOut=params.get("sessionTimeOut"),
            clientExclusionEnable=params.get("clientExclusionEnable"),
            clientExclusionTimeout=params.get("clientExclusionTimeout"),
            basicServiceSetMaxIdleEnable=params.get("basicServiceSetMaxIdleEnable"),
            basicServiceSetClientIdleTimeout=params.get(
                "basicServiceSetClientIdleTimeout"
            ),
            directedMulticastServiceEnable=params.get("directedMulticastServiceEnable"),
            neighborListEnable=params.get("neighborListEnable"),
            managementFrameProtectionClientprotection=params.get(
                "managementFrameProtectionClientprotection"
            ),
            nasOptions=params.get("nasOptions"),
            profileName=params.get("profileName"),
            aaaOverride=params.get("aaaOverride"),
            coverageHoleDetectionEnable=params.get("coverageHoleDetectionEnable"),
            protectedManagementFrame=params.get("protectedManagementFrame"),
            multiPSKSettings=params.get("multiPSKSettings"),
            clientRateLimit=params.get("clientRateLimit"),
            rsnCipherSuiteGcmp256=params.get("rsnCipherSuiteGcmp256"),
            rsnCipherSuiteCcmp256=params.get("rsnCipherSuiteCcmp256"),
            rsnCipherSuiteGcmp128=params.get("rsnCipherSuiteGcmp128"),
            rsnCipherSuiteCcmp128=params.get("rsnCipherSuiteCcmp128"),
            ghz6PolicyClientSteering=params.get("ghz6PolicyClientSteering"),
            isAuthKey8021x=params.get("isAuthKey8021x"),
            isAuthKey8021xPlusFT=params.get("isAuthKey8021xPlusFT"),
            isAuthKey8021x_SHA256=params.get("isAuthKey8021x_SHA256"),
            isAuthKeySae=params.get("isAuthKeySae"),
            isAuthKeySaePlusFT=params.get("isAuthKeySaePlusFT"),
            isAuthKeyPSK=params.get("isAuthKeyPSK"),
            isAuthKeyPSKPlusFT=params.get("isAuthKeyPSKPlusFT"),
            isAuthKeyOWE=params.get("isAuthKeyOWE"),
            isAuthKeyEasyPSK=params.get("isAuthKeyEasyPSK"),
            isAuthKeyPSKSHA256=params.get("isAuthKeyPSKSHA256"),
            openSsid=params.get("openSsid"),
            wlanBandSelectEnable=params.get("wlanBandSelectEnable"),
            isEnabled=params.get("isEnabled"),
            authServers=params.get("authServers"),
            acctServers=params.get("acctServers"),
            egressQos=params.get("egressQos"),
            ingressQos=params.get("ingressQos"),
            wlanType=params.get("wlanType"),
            l3AuthType=params.get("l3AuthType"),
            authServer=params.get("authServer"),
            externalAuthIpAddress=params.get("externalAuthIpAddress"),
            webPassthrough=params.get("webPassthrough"),
            sleepingClientEnable=params.get("sleepingClientEnable"),
            sleepingClientTimeout=params.get("sleepingClientTimeout"),
            aclName=params.get("aclName"),
            isPosturingEnabled=params.get("isPosturingEnabled"),
            isAuthKeySuiteB1x=params.get("isAuthKeySuiteB1x"),
            isAuthKeySuiteB1921x=params.get("isAuthKeySuiteB1921x"),
            isAuthKeySaeExt=params.get("isAuthKeySaeExt"),
            isAuthKeySaeExtPlusFT=params.get("isAuthKeySaeExtPlusFT"),
            isApBeaconProtectionEnabled=params.get("isApBeaconProtectionEnabled"),
            ghz24Policy=params.get("ghz24Policy"),
            cckmTsfTolerance=params.get("cckmTsfTolerance"),
            isCckmEnabled=params.get("isCckmEnabled"),
            isHex=params.get("isHex"),
            isRandomMacFilterEnabled=params.get("isRandomMacFilterEnabled"),
            fastTransitionOverTheDistributedSystemEnable=params.get(
                "fastTransitionOverTheDistributedSystemEnable"
            ),
            isRadiusProfilingEnabled=params.get("isRadiusProfilingEnabled"),
            policyProfileName=params.get("policyProfileName"),
            site_id=params.get("siteId"),
            id=params.get("id"),
        )
        return new_object

    def run(self, tmp=None, task_vars=None):
        self._task.diff = False
        self._result = super(ActionModule, self).run(tmp, task_vars)
        self._result["changed"] = False
        self._check_argspec()

        dnac = DNACSDK(params=self._task.args)

        response = dnac.exec(
            family="wireless",
            function="update_or_overridessid",
            op_modifies=True,
            params=self.get_object(self._task.args),
        )
        self._result.update(dict(dnac_response=response))
        self._result.update(dnac.exit_json())
        return self._result



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_rogue_additional_details
short_description: Resource module for Security Rogue
  Additional Details
description:
  - Manage operation create of the resource Security
    Rogue Additional Details. - > This API provides
    additional information of the rogue threats with
    details at BSSID level. The additional information
    includes Switch Port details in case of Rogue on
    Wire, first time when the rogue is seen in the network
    etc.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  endTime:
    description: This is the epoch end time in milliseconds
      upto which data need to be fetched. Default value
      is current time.
    type: float
  limit:
    description: The maximum number of entries to return.
      Default value is 1000.
    type: float
  offset:
    description: The offset of the first item in the
      collection to return. Default value is 1.
    type: float
  siteId:
    description: Filter Rogues by location. Site IDs
      information can be fetched from "Get Site" API.
    elements: str
    type: list
  startTime:
    description: This is the epoch start time in milliseconds
      from which data need to be fetched. Default value
      is 24 hours earlier to endTime.
    type: float
  threatLevel:
    description: Filter Rogues by Threat Level. Threat
      Level information can be fetched from "Get Threat
      Levels" API.
    elements: str
    type: list
  threatType:
    description: Filter Rogues by Threat Type. Threat
      Type information can be fetched from "Get Threat
      Types" API.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      RogueAdditionalDetails
    description: Complete reference of the RogueAdditionalDetails
      API.
    link: https://developer.cisco.com/docs/dna-center/#!rogue-additional-details
notes:
  - SDK Method used are
    devices.Devices.rogue_additional_details,
  - Paths used are
    post /dna/intent/api/v1/security/rogue/additional/details,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.security_rogue_additional_details:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    endTime: 0
    limit: 0
    offset: 0
    siteId:
      - string
    startTime: 0
    threatLevel:
      - string
    threatType:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "macAddress": "string",
          "mldMacAddress": "string",
          "updatedTime": 0,
          "createdTime": 0,
          "threatType": "string",
          "threatLevel": "string",
          "apName": "string",
          "detectingAPMac": "string",
          "ssid": "string",
          "containment": "string",
          "radioType": "string",
          "controllerIp": "string",
          "controllerName": "string",
          "channelNumber": "string",
          "siteNameHierarchy": "string",
          "encryption": "string",
          "switchIp": "string",
          "switchName": "string",
          "portDescription": "string"
        }
      ],
      "totalCount": 0,
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: backups_id
short_description: Resource module for Backups Id
description:
  - Manage operation delete of the resource Backups
    Id. - > This api is used to trigger delete workflow
    of a specific backup based on the provided `id`
    Obtain the `id` from the id attribute in the response
    of the `/dna/system/api/v1/backups` API. To monitor
    the progress and completion of the backup deletion
    , please call `/dna/system/api/v1/backupRestoreExecutions/{id}`
    api , where id is the taskId attribute from the
    response of the curent endpoint.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. The `id` of the
      backup to be deleted.Obtain the 'id' from the
      id attribute in the response of the `/dna/system/api/v1/backups`
      API.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Backup
      DeleteBackup
    description: Complete reference of the DeleteBackup
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-backup
notes:
  - SDK Method used are
    backup.Backup.delete_backup,
  - Paths used are
    delete /dna/system/api/v1/backups/{id},
"""

EXAMPLES = r"""
---
- name: Delete by id
  cisco.dnac.backups_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {}
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_advisories_trigger_scan
short_description: Resource module for Security Advisories
  Trigger Scan
description:
  - Manage operation create of the resource Security
    Advisories Trigger Scan. - > Triggers a security
    advisories scan for the supported network devices.
    The supported devices are switches, routers and
    wireless controllers with IOS and IOS-XE. If a device
    is not supported, the SecurityAdvisoryNetworkDevice
    scanStatus will be Failed with appropriate comments.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  failedDevicesOnly:
    description: FailedDevicesOnly query parameter.
      Used to specify if the scan should run only for
      the network devices that failed during the previous
      scan. If not specified, this parameter defaults
      to false.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Compliance
      TriggersASecurityAdvisoriesScanForTheSupportedNetworkDevices
    description: Complete reference of the TriggersASecurityAdvisoriesScanForTheSupportedNetworkDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!triggers-a-security-advisories-scan-for-the-supported-network-devices
notes:
  - SDK Method used are
    compliance.Compliance.triggers_a_security_advisories_scan_for_the_supported_network_devices,
  - Paths used are
    post /dna/intent/api/v1/securityAdvisories/triggerScan,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.security_advisories_trigger_scan:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    failedDevicesOnly: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_bugs_results_network_devices_info
short_description: Information module for Network Bugs
  Results Network Devices
description:
  - Get all Network Bugs Results Network Devices.
  - Get network bug devices.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceId:
    description:
      - NetworkDeviceId query parameter. Id of the network
        device.
    type: str
  scanMode:
    description:
      - >
        ScanMode query parameter. Mode or the criteria
        using which the network device was scanned.
        Available values ESSENTIALS, ADVANTAGE, CX_CLOUD,
        NOT_AVAILABLE.
    type: str
  scanStatus:
    description:
      - >
        ScanStatus query parameter. Status of the scan
        on the network device. Available values NOT_SCANNED,
        IN_PROGRESS, SUCCESS, FAILED, FALL_BACK.
    type: str
  bugCount:
    description:
      - BugCount query parameter. Return network devices
        with bugCount greater than this bugCount.
    type: float
  offset:
    description:
      - >
        Offset query parameter. The first record to
        show for this page; the first record is numbered
        1. Default value is 1.
    type: int
  limit:
    description:
      - >
        Limit query parameter. The number of records
        to show for this page. Minimum value is 1. Maximum
        value is 500. Default value is 500.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A property within the
        response to sort by.
    type: str
  order:
    description:
      - >
        Order query parameter. Whether ascending or
        descending order should be used to sort the
        response. Available values asc, desc. Default
        value is asc.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Compliance
      GetNetworkBugDevices
    description: Complete reference of the GetNetworkBugDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-network-bug-devices
notes:
  - SDK Method used are
    compliance.Compliance.get_network_bug_devices,
  - Paths used are
    get /dna/intent/api/v1/networkBugs/results/networkDevices,
"""

EXAMPLES = r"""
---
- name: Get all Network Bugs Results Network Devices
  cisco.dnac.network_bugs_results_network_devices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    networkDeviceId: string
    scanMode: string
    scanStatus: string
    bugCount: 0
    offset: 0
    limit: 0
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "networkDeviceId": "string",
          "bugCount": 0,
          "scanMode": "string",
          "scanStatus": "string",
          "comments": "string",
          "lastScanTime": 0
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_delete_without_cleanup
short_description: Resource module for Network Devices
  Delete Without Cleanup
description:
  - Manage operation create of the resource Network
    Devices Delete Without Cleanup. - > This API endpoint
    facilitates the deletion of a network device without
    performing configuration cleanup on the device.
    To delete a device via API, you must have permission
    to provision the network device. Although the API
    operation does not change the device configuration,
    removing a device without cleaning up its configuration
    could lead to a network behaviour that is not consistent
    with the configurations that are known to the system.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: The unique identifier of the network
      device to be deleted.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      DeleteANetworkDeviceWithoutConfigurationCleanup
    description: Complete reference of the DeleteANetworkDeviceWithoutConfigurationCleanup
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-a-network-device-without-configuration-cleanup
notes:
  - SDK Method used are
    devices.Devices.delete_a_network_device_without_configuration_cleanup,
  - Paths used are
    post /dna/intent/api/v1/networkDevices/deleteWithoutCleanup,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_devices_delete_without_cleanup:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: virtual_network_health_summaries_id_info
short_description: Information module for Virtual Network
  Health Summaries Id
description:
  - Get Virtual Network Health Summaries Id by id. -
    > Get health summary for a specific Virtual Network
    by providing the unique virtual networks id in the
    url path. L2 Virtual Networks are only included
    in health reporting for EVPN protocol deployments.
    The special Layer 3 VN called "INFRA_VN" is also
    not included for user access through Assurance virtualNetworkHealthSummaries
    APIS. Please find INFRA_VN related health metrics
    under /data/api/v1/fabricSiteHealthSummaries Ex
    attributes "pubsubInfraVnGoodHealthPercentage" and
    "bgpPeerInfraVnScoreGoodHealthPercentage" .
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Unique virtual networks id.
    type: str
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  attribute:
    description:
      - Attribute query parameter. The interested fields
        in the request. For valid attributes, verify
        the documentation.
    type: str
  view:
    description:
      - >
        View query parameter. The specific summary view
        being requested. This is an optional parameter
        which can be passed to get one or more of the
        specific health data summaries associated with
        virtual networks.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA ReadVirtualNetworkWithItsHealthSummaryFromId
    description: Complete reference of the ReadVirtualNetworkWithItsHealthSummaryFromId
      API.
    link: https://developer.cisco.com/docs/dna-center/#!read-virtual-network-with-its-health-summary-from-id
notes:
  - SDK Method used are
    sda.Sda.read_virtual_network_with_its_health_summary_from_id,
  - Paths used are
    get /dna/data/api/v1/virtualNetworkHealthSummaries/{id},
"""

EXAMPLES = r"""
---
- name: Get Virtual Network Health Summaries Id by id
  cisco.dnac.virtual_network_health_summaries_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    endTime: 0
    startTime: 0
    attribute: string
    view: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "vlan": "string",
        "vnid": "string",
        "layer": "string",
        "associatedL3Vn": "string",
        "totalEndpoints": 0,
        "totalFabricSites": 0,
        "goodHealthPercentage": 0,
        "goodHealthDeviceCount": 0,
        "totalHealthDeviceCount": 0,
        "fairHealthDeviceCount": 0,
        "poorHealthDeviceCount": 0,
        "noHealthDeviceCount": 0,
        "vnFabricControlPlaneGoodHealthPercentage": 0,
        "vnFabricControlPlaneTotalDeviceCount": 0,
        "vnFabricControlPlaneGoodHealthDeviceCount": 0,
        "vnFabricControlPlanePoorHealthDeviceCount": 0,
        "vnFabricControlPlaneFairHealthDeviceCount": 0,
        "vnFabricControlPlaneNoHealthDeviceCount": 0,
        "vnServicesHealthPercentage": 0,
        "vnServicesTotalDeviceCount": 0,
        "vnServicesGoodHealthDeviceCount": 0,
        "vnServicesPoorHealthDeviceCount": 0,
        "vnServicesFairHealthDeviceCount": 0,
        "vnServicesNoHealthDeviceCount": 0,
        "vnExitHealthPercentage": 0,
        "vnExitTotalDeviceCount": 0,
        "vnExitGoodHealthDeviceCount": 0,
        "vnExitPoorHealthDeviceCount": 0,
        "vnExitFairHealthDeviceCount": 0,
        "vnExitNoHealthDeviceCount": 0,
        "vnStatusHealthPercentage": 0,
        "vnStatusTotalDeviceCount": 0,
        "vnStatusGoodHealthDeviceCount": 0,
        "vnStatusPoorHealthDeviceCount": 0,
        "vnStatusFairHealthDeviceCount": 0,
        "vnStatusNoHealthDeviceCount": 0,
        "pubsubSessionGoodHealthPercentage": 0,
        "pubsubSessionTotalDeviceCount": 0,
        "pubsubSessionGoodHealthDeviceCount": 0,
        "pubsubSessionPoorHealthDeviceCount": 0,
        "pubsubSessionFairHealthDeviceCount": 0,
        "pubsubSessionNoHealthDeviceCount": 0,
        "multiCastGoodHealthPercentage": 0,
        "multiCastTotalDeviceCount": 0,
        "multiCastGoodHealthDeviceCount": 0,
        "multiCastPoorHealthDeviceCount": 0,
        "multiCastFairHealthDeviceCount": 0,
        "internetAvailGoodHealthPercentage": 0,
        "internetAvailTotalDeviceCount": 0,
        "internetAvailGoodHealthDeviceCount": 0,
        "internetAvailPoorHealthDeviceCount": 0,
        "internetAvailFairHealthDeviceCount": 0,
        "internetAvailNoHealthDeviceCount": 0,
        "bgpPeerGoodHealthPercentage": 0,
        "bgpPeerTotalDeviceCount": 0,
        "bgpPeerGoodHealthDeviceCount": 0,
        "bgpPeerPoorHealthDeviceCount": 0,
        "bgpPeerFairHealthDeviceCount": 0,
        "bgpPeerNoHealthDeviceCount": 0,
        "vniGoodHealthPercentage": 0,
        "vniTotalDeviceCount": 0,
        "vniGoodHealthDeviceCount": 0,
        "vniPoorHealthDeviceCount": 0,
        "vniFairHealthDeviceCount": 0,
        "vniNoHealthDeviceCount": 0,
        "networkProtocol": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: health_score_definitions_info
short_description: Information module for Health Score
  Definitions
description:
  - Get all Health Score Definitions.
  - Get Health Score Definitions by id.
  - Get all health score defintions. - > Get health
    score defintion for the given id. Definition includes
    all properties from HealthScoreDefinition schema
    by default. For detailed information about the usage
    of the API, please refer to the Open API specification
    document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-issueAndHealthDefinitions-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  deviceType:
    description:
      - >
        DeviceType query parameter. These are the device
        families supported for health score definitions.
        If no input is made on device family, all device
        families are considered.
    type: str
  id:
    description:
      - >
        Id query parameter. The definition identifier.
        Examples id=015d9cba-4f53-4087-8317-7e49e5ffef46
        (single entity id request) id=015d9cba-4f53-4087-8317-7e49e5ffef46&id=015d9cba-4f53-4087-8317-7e49e5ffef47
        (multiple ids in the query param).
    type: str
  includeForOverallHealth:
    description:
      - >
        IncludeForOverallHealth query parameter. The
        inclusion status of the issue definition, either
        true or false. True indicates that particular
        health metric is included in overall health
        computation, otherwise false. By default it's
        set to true.
    type: bool
  attribute:
    description:
      - >
        Attribute query parameter. These are the attributes
        supported in health score definitions response.
        By default, all properties are sent in response.
    type: str
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: int
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetAllHealthScoreDefinitionsForGivenFilters
    description: Complete reference of the GetAllHealthScoreDefinitionsForGivenFilters
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-all-health-score-definitions-for-given-filters
  - name: Cisco DNA Center documentation for Devices
      GetHealthScoreDefinitionForTheGivenId
    description: Complete reference of the GetHealthScoreDefinitionForTheGivenId
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-health-score-definition-for-the-given-id
notes:
  - SDK Method used are
    devices.Devices.get_all_health_score_definitions_for_given_filters,
    devices.Devices.get_health_score_definition_for_the_given_id,
  - Paths used are
    get /dna/intent/api/v1/healthScoreDefinitions,
    get /dna/intent/api/v1/healthScoreDefinitions/{id},
"""

EXAMPLES = r"""
---
- name: Get all Health Score Definitions
  cisco.dnac.health_score_definitions_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    deviceType: string
    id: string
    includeForOverallHealth: true
    attribute: string
    offset: 0
    limit: 0
  register: result
- name: Get Health Score Definitions by id
  cisco.dnac.health_score_definitions_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "name": "string",
          "displayName": "string",
          "deviceFamily": "string",
          "description": "string",
          "includeForOverallHealth": true,
          "definitionStatus": "string",
          "thresholdValue": 0,
          "synchronizeToIssueThreshold": true,
          "lastModified": "string"
        }
      ]
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: telemetry_settings_apply
short_description: Resource module for Telemetry Settings
  Apply
description:
  - Manage operation create of the resource Telemetry
    Settings Apply. - > Update a devices telemetry settings
    to conform to the telemetry settings for its site.
    One Task is created to track the update, for more
    granular status tracking, split your devices into
    multiple requests.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deviceIds:
    description: The list of device Ids to perform the
      provisioning against.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Network
      Settings UpdateADevicesTelemetrySettingsToConformToTheTelemetrySettingsForItsSite
    description: Complete reference of the UpdateADevicesTelemetrySettingsToConformToTheTelemetrySettingsForItsSite
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-a-devices-telemetry-settings-to-conform-to-the-telemetry-settings-for-its-site
notes:
  - SDK Method used are
    network_settings.NetworkSettings.update_a_devices_telemetry_settings_to_conform_to_the_telemetry_settings_for_its_site,
  - Paths used are
    post /dna/intent/api/v1/telemetrySettings/apply,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.telemetry_settings_apply:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deviceIds:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: field_notices_results_notices_id_network_devices_count_info
short_description: Information module for Field Notices
  Results Notices Id Network Devices Count
description:
  - Get all Field Notices Results Notices Id Network
    Devices Count.
  - Get count of field notice network devices for the
    notice.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Id of the field notice.
    type: str
  networkDeviceId:
    description:
      - NetworkDeviceId query parameter. Id of the network
        device.
    type: str
  scanStatus:
    description:
      - >
        ScanStatus query parameter. Status of the scan
        on the network device. Available values NOT_SCANNED,
        IN_PROGRESS, SUCCESS, FAILED.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Compliance
      GetCountOfFieldNoticeNetworkDevicesForTheNotice
    description: Complete reference of the GetCountOfFieldNoticeNetworkDevicesForTheNotice
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-count-of-field-notice-network-devices-for-the-notice
notes:
  - SDK Method used are
    compliance.Compliance.get_count_of_field_notice_network_devices_for_the_notice,
  - Paths used are
    get /dna/intent/api/v1/fieldNotices/results/notices/{id}/networkDevices/count,
"""

EXAMPLES = r"""
---
- name: Get all Field Notices Results Notices Id Network
    Devices Count
  cisco.dnac.field_notices_results_notices_id_network_devices_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    networkDeviceId: string
    scanStatus: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "count": 0
      }
    }
"""
